{% extends "layout.html" %}
{% import "articles/_contributors.html" as contributor with context %}

{% block title %}
L'Art de bien mélanger un deck
{% endblock %}

{% block content %}
<h1>{{ _("L'Art de bien mélanger un deck") }}</h1>
{{ contributor.zombie33() }}

{% trans trimmed
	img_proba_main_depart='<img src="%(url)s"/>'|format(url=url_for('static', filename='img/proba_main_depart.png'))|safe,
	img_melange_paquet='<img src="%(url)s"/>'|format(url=url_for('static', filename='img/melange_paquet.png'))|safe,
	img_courbe_diaconis='<img src="%(url)s"/>'|format(url=url_for('static', filename='img/courbe_diaconis.png'))|safe,
	img_melange_francais='<img src="%(url)s"/>'|format(url=url_for('static', filename='img/melange_francais.png'))|safe,
	img_melange_tas='<img src="%(url)s"/>'|format(url=url_for('static', filename='img/melange_tas.png'))|safe,

	cockatrice=external("https://cockatrice.github.io/", "Cockatrice"),
	mtgo=external("https://magic.wizards.com/en/mtgo", "MTGO"),
	mtga=external("https://magic.wizards.com/fr/mtgarena", "Magic Arena"),

	loi_hypergeometrique=link("/articles/la-loi-hypergeometrique", _("loi hypergéométrique"))
%}
<p>
	L'objectif de cet article est de détailler les mathématiques derrière les mélanges, que ce
	soit avec des cartes réelles ou virtuelles via les plateformes de jeu en ligne telles que
	{{ cockatrice }}, {{ mtgo }} ou encore {{ mtga }}.
</p>
<p>
	Le mélange de cartes, que ce soit dans la vie réelle ou lors de parties simulées par
	ordinateur, est un sujet qui a fait l’objet de nombreuses études en mathématiques et en
	algorithmique. Cependant, la plupart des articles de vulgarisations que l’on peut trouver sur
	le sujet sont souvent succints et ne traitent dans leurs exemples que des jeux de 32 et 52
	cartes alors que nous mélangeons des bibliothèques de toutes tailles.
</p>

<h2>Comment sont effectués les mélanges sur les plateformes de jeu en ligne ?</h2>
<p>
	Le mélange de cartes Magic par les plateformes de jeu en ligne revient à numéroter les cartes
	et d'effectuer des permutations entre ces numéros. Voici l'ensemble des six permutations
	possibles pour un ensemble de trois cartes :
</p>
<ul>
	<li>[1;2;3] : On ne change pas l’ordre des cartes ;</li>
	<li>[1;3;2] : On échange la deuxième et la troisième carte ;</li>
	<li>[2;1;3] : On échange la première et la deuxième carte ;</li>
	<li>[2;3;1] : On coupe le paquet après une carte ;</li>
	<li>[3;1;2] : On coupe le paquet après deux cartes ;</li>
	<li>[3;2;1] : On échange la première et la troisième carte.</li>
</ul>
<p>
	Le nombre de permutations augmente de manière exponentielle selon le nombre de cartes dans
	un deck : dix permutations pour quatre cartes, quinze pour cinq, vingt-et-une pour six, ...
</p>
<p>
	On appelle <em>mélangeur parfait</em> un mélangeur qui associe à chacunes de ces permutations
	la même probabilité. Il faut donc être en mesure de déterminer le nombre de ces permutations.
	Pour un deck de soixante cartes, le nombre de permutations possibles est supérieur au nombre
	d'atomes dans l'univers : <em>8320987112741390144276341183223364380754172606361245952449277696409600000000000000</em>.
	L'objectif est donc de se rapprocher autant que possible de ce mélangeur parfait.
</p>
<p>
	Un algorithme ne peut pas générer de phénomènes aléatoires car il est <em>déterministe</em>. Il
	peut seulement générer des résultats très difficilement prévisibles et en apparence aléatoire.
	C'est le cas des algorithmes utilisés sur les plateformes de jeux en ligne. Ces algorithmes
	sont suffisamment performants pour être considérés comme <em>suffisamment aléatoires</em>.
</p>
<p>
	La suite de l'article permettra de mettre en évidence un moyen de mesurer cet aspect
	<em>suffisamment aléatoire</em> mais ne traitera pas du biais cognitif existant chez les
	joueuses et les joueurs qui estiment avoir <em>trop fréquemment</em> des soucis de distribution
	de terrains dans leur deck.
</p>
<p>
	Pour illustrer le propos, le graphique ci-dessous décrit la probabilité d'avoir un certain
	nombre de terrains en main de départ avec un deck de 60 cartes contenant 24 terrains. Ce
	graphique a été obtenu avec un calcul de probabilité selon une {{ loi_hypergeometrique }} pour
	les valeurs bleues (c'est à dire pour un mélangeur parfait) et les valeurs rouges ont été
	obtenues avec 13000 mains de départ obtenues sur MTGO.
</p>
{{ img_proba_main_depart }}

<h2>Comment bien mélanger son deck ?</h2>
<p>
	Cette section passe en revue certains types de mélanges pour voir lesquels sont efficaces et
	lesquels ne le sont pas. Un des mélanges présentés ici peut être détourné et servir de moyen de
	tricher pour un joueur ou une joueuse mal intentionnée.
</p>

<h3>Le mélange américain</h3>
<p>
	Ce mélange consiste à séparer le tas de cartes en deux paquets approximativement égaux puis de
	former un troisième paquet de cartes en alternant approximativement les cartes de chaque
	paquet. L'aléatoire du mélange vient du fait que toutes les manipulation sont approximatives.
	Il existe plusieurs méthodes pour effectuer ce mélange :
</p>
<ul>
	<li>
		<p>
			Le mélange en mitraillette (<em>Riffle Shuffle</em>) :
		</p>
		<p>
			Il s’agit de la technique la plus utilisée lorsque l’on mélange les cartes car
			c'est la plus rapide. Elle est utilisée par les croupiers dans les casinos
			notamment.
		</p>
	</li>
	<li>
		<p>
			Le mélange par écrasement (<em>Mashing Shuffle</em>) :
		</p>
		<p>
			Il s’agit de la technique utilisée par les joueurs de cartes à collectionner
			car ces cartes et les protections supportent assez mal la courbure imposée par le
			mélange américain.
		</p>
	</li>
</ul>
{{ img_melange_paquet }}
<p>
	Après avoir effectué <strong>plusieurs</strong> fois ce mélange, le paquet est considéré comme
	étant bien mélangé. Tout réside dans le sens que l'on donne à « plusieurs ».
</p>
<div class="tip">
	<h3>Tour de magie</h3>
	<p>
		<em>
			Voici tour de magie imaginé au début du XXème siècle par deux magiciens Williams et
			Jordan.
		</em>
	</p>
	<p>
		Le tour consiste à demander à une personne de prendre un jeu de cartes puis d'effectuer
		successivement une coupe, un riffle shuffle, une coupe, un riffle shuffle et terminer par
		une coupe. Puis cette personne doit piocher une carte et la remettre au hasard dans le
		paquet. Le magicien se saisit alors du jeu et étale le paquet face visible devant lui et
		après un temps de réflexion fini par retrouver la carte choisie, en moyenne 9 fois sur 10.
	</p>
	<p>
		Cela demande évidemment un entrainement particulier mais rien d'extraordinaire. Le magicien
		doit au préalable avoir appris l’ordre initial des cartes et savoir quoi regarder. Au
		final, le point important dans cet exemple est que si l’on n’apporte pas suffisamment de
		chaos à un système ordonné au préalable, il est toujours possible de tirer des informations
		du mélange obtenu avec une marge d’erreur qui peut être étonnamment faible.
	</p>
</div>
<p>
	La question qui se pose est alors la suivante : Combien de fois donc doit on effectuer de
	mélange américain pour obtenir une répartition « suffisamment » aléatoire pour rendre toute
	triche impossible ?
</p>
<p>
	La réponse à cette question a été apportée assez récemment, en 1992, par un mathématicien
	du nom de Persi Diaconis qui fut auparavant un magicien professionnel. Pour répondre à cette
	question, Diaconis introduit un moyen de mesurer l’écart entre un mélangeur donné et le
	mélangeur parfait que l’on désire obtenir. Cet indicateur est un nombre entre 0 et 1 et plus il
	est proche de 0, plus notre mélange est efficace. Sachant cela, voici les courbes que fournit
	cet indicateur lorsque varie le nombre de mélanges américains.
</p>
{{ img_courbe_diaconis }}
<p>
	Ce graphique est obtenu à l’aide des probabilités exactes et théorique et non d’un générateur
	aléatoire.
</p>
<p>
	Les premiers mélanges effectués n’ont quasiment aucun effet sur l'indicateur. Pour être
	« suffisamment » mélangé, il faut que l'indicateur soit au plus égal à 0,5, ce qui revient à
	mélanger au moins 6, 7 ou 8 fois pour des jeux ayant respectivement 40, 60 et 99 cartes.
</p>
<p>
	Cela peut paraitre beaucoup et fastidieux mais voici un exemple concret
	de tricherie difficilement repérable, réalisable lorsqu’on ne mélange pas suffisamment un jeu
	et qui ne demande ni une adresse ni une mémoire excessive.
</p>
<div class="tip">
	<h3>Un mélange bien ordonné</h3>
	<p>
		Au milieu d’une partie de Magic, un effet permet de chercher une certaine carte dans la
		bibliothèque, d'une taille d'environ 50 cartes. Le joueur se saisit alors de son deck à
		l’envers et le parcourt jusqu’à trouver la carte recherchée. Lors de cette opération, il
		doit compter 8 cartes puis retenir les 5 suivantes. Quand il a trouvé la carte recherchée,
		il effectue un seul mélange américain et pose le deck devant votre adversaire pour qu’il le
		coupe. Si l’adversaire effectue une simple coupe machinalement, il l’effectuera
		approximativement au milieu. Les cinq cartes alors retenues devraient parvenir assez tôt
		par la suite dans l’ordre inverse dans lequel elle ont été mémorisées et chacune séparée
		approximativement par une carte. Cela n’a l’air de rien, mais cela fournit assez facilement
		beaucoup d’informations au joueur.
	</p>
</div>

<h3>Le mélange Français</h3>
<p>
	Le mélange français, <em>Overhand Shuffle</em>, ainsi que le mélange indien,
	<em>Indian Shuffle</em>, consistent à séparer le paquet de cartes en un nombre aléatoire de
	paquets puis à inverser leur ordre. La seule chose qui différencie le mélange français et le
	mélange indien est la manière d'exécuter ce mélange mais le résultat est essentiellement le
	même.
</p>
{{ img_melange_francais }}
<p>
	En utilisant l’indicateur donné plus haut, le nombre de mélanges français nécessaires pour
	générer un mélange aléatoire est de l’ordre de 10 000. Il s’agit donc clairement d’un mélange à
	éviter pour bien mélanger un paquet et il faut de même se méfier grandement des adversaires qui
	utilisent ce mélange lors des tournois importants. En effet, ce type de mélange peut être
	détourné assez facilement pour effectuer un ordonnancement du paquet lors du mélange, le
	<em>stackage</em>.
</p>
<p>
	Le stackage est une technique assez répandue qui consiste, durant le mélange
	d'un paquet, à en observer la carte la plus basse et ensuite à choisir de mettre cette carte au
	dessus du paquet ou non. L'utilisation la plus fréquente revient à organiser les cartes du
	dessus du paquet pour que l'adversaire se retrouve dans une situation où il ne soit pas
	possible de garder la main et de procéder à un mulligan. Une simple coupe permet de casser ce
	tri.
</p>

<h3>Le mélange par tas</h3>
<p>
	Le mélange par tas consiste à faire un certain nombre de tas de cartes (entre 3 et 7
	généralement), à les remplir alternativement en suivant un ordre cyclique, puis à les
	rassembler dans l'ordre inverse où ils ont été créés (premier tas en dernière position, second
	tas en avant dernière position, etc). Il s'agit d'un mélange populaire parmi les joueurs et
	joueuses de Magic et d'autres jeux de cartes à collectionner.
</p>
{{ img_melange_tas }}
<p>
	Il ne s'agit pas d'un mélange à proprement parler. En effet, cette manipulation du paquet
	résulte dans un nouvel ordre des cartes. Cet ordre peut être déterminé d'après les
	manipulations précédentes. C'est pourquoi ce type de manipulation doit toujours être combiné à
	une série de mélanges américains. L'utilisation seule de ces manipulations fait, par exemple,
	que les première et dernière cartes sont permutées à chaque itération ; deux itérations et la
	carte du dessus restera la même.
</p>
<p>
	En résumé, cette manipulation doit toujours être accompagnée d’une série classique de mélanges
	américains. Mais même dans ce cas de figure, elle n’apporte rien d’un point de vu strictement
	mathématique. C’est d’ailleurs assez compréhensible étant donné que ces manipulations suivent
	clairement un schéma prédéfini qui n’a absolument rien d’aléatoire.
</p>
<p>
	Malgré cela, ce « mélange » est très répandu parmi les joueurs de Magic et d'autres jeux de
	cartes à collectionner mais on ne retrouve pas cette pratique au Poker ou au Bridge, par
	exemple. En effet, les cartes à collectionner ne sont pas faites pour être mélangées un grand
	nombre de fois : elles sont chères et s'abîment très vite. Par conséquence, les joueurs
	utilisent des protections pour leurs cartes. Cependant ces dernières ont tendance à coller les
	unes aux autres, ce qui crée un biais qui n'est absolument pas négligeable lorsqu'on effectue
	un mélange américain. Le seul intérêt d'un « mélange » par tas est de séparer toutes les cartes
	une à une pour s’assurer que deux cartes précédemment voisines ne le restent pas après mélange.
</p>

<h3>Le mélange Faro</h3>
<p>
	Le Faro est un mélange qui est souvent confondu avec le mélange américain mais son intérêt est
	toutefois très différent : le Faro est un mélange américain parfait. Le paquet de cartes est
	coupé en deux paquets égaux qui sont rassemblés en alternant exactement les cartes de chaque
	paquet une par une. Ce mélange parfait est appelé le Faro et il en existe deux :
	<em>In Faro</em> (IF) pour lequel la première carte du paquet reste à la même position et
	<em>Out Faro</em> (OF) pour lequel la première carte arrive en seconde position.
</p>
<p>
	Le Faro, aussi appelé Pharaon, était un jeu d'argent populaire au XVIIIème siècle et c'est
	justement pour ce jeu qu'à été décrit pour la première fois dans un écrit anonyme de 1726,
	cette méthode comme moyen de tricher. Le principal but de cette opération n’est absolument pas
	de mélanger le jeu de cartes, mais bel est bien de tricher, de faire croire aux autres
	personnes que le deck est mélangé alors qu’il ne l’est absolument pas. Il existe de nombreux
	tours de prestidigitation avec des jeux de 32 cartes qui reposent sur ce type de manipulation.
</p>
<p>
	En pratique, un Faro n’est pas réalisable en quelques seconde sur des cartes Magic avec des
	protèges cartes. Toutefois, il n’est pas exclu que cela soit faisable par un prestidigitateur
	aguerri avec un paquet de quarante cartes neuves sans protection. À partir de là, un joueur qui
	maîtriserait cette manipulation pourrait effectuer les manipulations décrites ci-dessous :
</p>
<ul>
	<li>
		Dix Out Faro successifs permettent de classer le deck en sens inverse.
	</li>
	<li>
		Trois In Faro successifs suivi d’un mélange en 8 tas permet de classer le deck en sens
		inverse.
	</li>
	<li>
		Un mélange en 4 tas suivi de deux In Faro permet de classer le deck en sens inverse.
	</li>
	<li>
		Deux In Faro suivi d’un mélange en 4 tas permet de classer le deck en sens inverse.
	</li>
</ul>
<p>
	Si on effectue deux manipulations successives qui classe le deck en sens inverse, cela revient
	à ne pas mélanger son jeu.
</p>

<div class="tip">
	<h3>Ce qu'il faut retenir</h3>
	<ul>
		<li>
			Le mélangeur parfait n'existe pas.
		</li>
		<li>
			Les mélangeurs informatiques sont suffisamment performants pour qu'on puisse se fier à
			eux. Tout sentiment d'injustice de la part des joueurs sur les mains de départ qu'ils
			pourraient obtenir n'est qu'un biais cognitif.
		</li>
		<li>
			Pour bien mélanger un deck de 40, 60 ou 99 cartes il faut effectuer 6, 7 ou 8 mélanges
			américains ou par écrasements consécutifs. Toutefois dans le cas de mélange par
			écrasements, cela doit s'accompagner d'un mélange par tas afin de décoller
			chacune des cartes.
		</li>
		<li>
			Le mélange français n'est absolument pas fiable et permet à certains joueurs
			d'effectuer des techniques de stackage de votre deck.
		</li>
		<li>
			Un deck mal ou insuffisamment mélangé peut permettre à un adversaire mal intentionné de
			tricher facilement. Ne sous-estimez jamais l'importance de bien mélanger son deck ou
			celui de l'adversaire même pour des faits de jeux aussi anodins que l'activation d'un
			fetchland.
		</li>
	</ul>
</div>
{% endtrans %}
{% endblock %}
