{% extends "layout.html" %}

{% block title %}
Les Mana dorks
{% endblock %}

{% block content %}
{% trans trimmed
	forest=card("Forest", _("Forêt"))
%}
<h1>Les mana dorks</h1>
<p>
	Les <em>dorks</em> sont des créatures avec une force et une endurance peu impressionnantes au
	point où ces créatures sont considérées comme « incapables d'attaquer ». Les dorks ont
	cependant d'autres capacités intéressantes, comme les <em>mana dorks</em> présentés ici qui,
	comme {{ llanowar_elves }}, s'engagent pour produire du mana.
</p>
<p>
	Les mana dorks sont les créatures vertes les plus jouées du format. Parmi elles
	{{ birds_of_paradise }}, {{ elvish_mystic }}, {{ fyndhorn_elves }} et {{ llanowar_elves }} se
	retrouvent dans la grande majorité des decks. {{ gilded_goose }} est à jouer lorsque le besoin
	d'accès au mana n'est pas permanent et que les jetons produits sont utilisables autrement.
</p>
<p>
	En s'éloignant de l'aspect strictement vert, {{ deathrite_shaman }} est un bon ajout lorsque le
	deck ne dépend pas des terrains dans son cimetière. {{ arbor_elf }} dégage une {{ forest }},
	cette créature ne produit pas directement du mana, il faut donc l'utiliser avant de lancer un
	sort ou d'activer une capacité. {{ boreal_druid }} produit du mana incolore qui a la
	caractérisque <em>neigeux</em>, cela peut être utile pour lancer des {{ arcums_astrolabe }} par
	exemple.
</p>
<p>
	Dépendant de l'identité couleur du deck, des dorks comme {{ avacyns_pilgrim }},
	{{ elves_of_deep_shadow }} ou {{ noble_hierarch }} peuvent être envisagés.
</p>
<p>
	D'autres créature aident à produire du mana et peuvent être assimilées aux mana dorks. C'est le
	cas de {{ lotus_cobra }} en particulier et de {{ radha_heir_to_keld }} voire de
	{{ klothys_god_of_destiny }} dans une moindre mesure.
</p>
<p>
	Les enchantements {{ utopia_sprawl }} et {{ wild_growth }} sont parfois considérés comme des
	<em>dork</em> du fait de leur faible coût et de leur jouabilité dès le premier tour. Selon ce
	qui est attendu des mana dorks, ces enchantements sont à considérer.
</p>
<div class="tip">
	<h3>Être un mana dork et être rentable en fin de partie</h3>
	<p>
		Il n'est pas impossible qu'un mana dork soit pioché en fin de partie. Cela peut-être une pioche désagréable si des outils ne sont pas intégrés au deck.
	</p>
	<p>
		Parmi ces outils, {{ skullclamp }} est la carte <em>par défaut</em>. Elle permet de
		remplacer le mana dork en deux autres cartes. Cet équipement est aussi intéressant car, en
		règle générale, la zone de commandement est occupée par une créature qui est voué à mourir,
		au moins une fois. D'autres équipements sont envisageables.
	</p>
	<p>
		Parmi les autres cartes se trouvent {{ survival_of_the_fittest }} pour remplacer
		directement le mana dork par quelque chose de plus imposant. Utilisant cette technique, il
		y a également {{ birthing_pod }} ou {{ fauna_shaman }}.
	</p>
	<p>
		D'autres identités couleur ont accès à {{ goblin_bombardment }} ou à
		{{ tortured_existence }} par exemple.
	</p>
</div>
{% endtrans %}
{% endblock %}
