{% extends "archetypes/_layout.html" %}
{% import "archetypes/_layout_wip.html" as layout with context %}
{% import "archetypes/titania-protector-of-argoth.json" as deck_json %}

{% block title %}
Titania, Protector of Argoth
{% endblock %}

{% block meta %}
<meta property="decklist" content='{{ deck_json | tojson }}' />
{% endblock %}

{% block archetype_name %}
<h1>Titania, Protector of Argoth</h1>
{% endblock %}

{% block archetype %}
{% trans trimmed %}
<h2>Présentation rapide</h2>
<p>
	La générale, {{ titania_protector_of_argoth }}, est une créature dont le coût en mana est assez
	élevé comparé à la moyenne du Duel Commander aux alentours de 4. De plus, sa faible endurance
	la rend sensible aux cartes comme {{ lightning_bolt }} jouée dans une grande majorité des decks
	le pouvant.
</p>
<p>
	Après cet état des lieux à charge contre {{ titania_protector_of_argoth }}, il faut noter ses
	points positifs. Sa capacité à ramener un terrain en jeu depuis le cimetière est un réel
	avantage car cela réduit virtuellement la taxe de commandant en ne demandant que de rejouer un
	terrain supplémentaire. De plus, sa capacité à générer des jetons de créature est le point fort
	le plus exploité dans ce deck.
</p>
{% endtrans %}
{% endblock %}
