{% extends "layout.html" %}

{% block title %}
Section Articles
{% endblock %}

{% block content %}
<h1>Articles</h1>
<p>
	{% trans %}
	Cette section explore la stratégie de <strong>Magic: the Gathering</strong>.
	{% endtrans %}
</p>

{{ bootstrap.card("Obsessive Search", "/articles/classifier-un-deck") }}
{{ bootstrap.card("Clockwork Swarm", "/articles/complexite-et-machine-de-turing")}}
{{ bootstrap.card("Compulsive Research", "/articles/construire-un-deck") }}
{{ bootstrap.card("Veil of Summer", "/articles/melanger-un-deck") }}

<p>
	<em>D'autres articles à venir ...</em>
</p>
{% endblock %}
