{% extends "layout.html" %}

{% block title %}
Le Ramp
{% endblock %}

{% block content %}
{% trans trimmed
	grosses_creatures=link("/cartes-thematiques/mecaniques-de-la-colorpie/les-grosses-creatures", _("des grosses créatures")),
	mana_dork=link("/cartes-thematiques/mecaniques-de-la-colorpie/les-mana-dorks", _("les mana dorks")),
	disponible=link("/cartes-thematiques/mecaniques-de-la-colorpie/les-mana-dorks", _("disponible")),
	cailloux="les <em>%(str)s</em>"|format(str="cailloux")|safe
%}
<h1>Le ramp</h1>
<p>
	Le <em>Ramp</em> est une mécanique qui correspond à obtenir une source de mana additionnelle et
	réutilisable en plus du terrain habituel. Cette mécanique tire son nom de {{ rampant_growth }}.
	Un deck utilisant cette mécanique joue souvent {{ grosses_creatures }}.
</p>
<p>
	Les sorts de ramp sont habituellement des rituels. Parmi les cartes jouées se trouvent
	{{ farseek }}, {{ into_the_north }}, {{ natures_lore }}, {{ rampant_growth }} et
	{{ three_visits }} à deux manas et {{ cultivate }}, {{ kodamas_reach }} et
	{{ search_for_tomorrow }} à trois manas.
</p>
<p>
	En plus de ces sorts, il arrive de voir {{ exploration }} et {{ explore }} qui modifient le
	nombre de terrains qu'il est possible de jouer à chaque tour, aussi appelé <em>land drop</em>.
	{{ restore }} est également considérée comme une carte de ramp.
</p>
<p>
	Il existe également des cartes qui permettent de mettre des terrains en main depuis la
	bibliothèque. Ce ne sont pas des cartes de ramp. Les plus fréquentes sont {{ expedition_map }},
	{{ land_grant }}, {{ safewright_quest }}, {{ sylvan_scrying }}, {{ tithe }} et
	{{ traverse_the_ulvenwald }}. Ces cartes sont jouées quand il est nécessaire de réunir
	plusieurs terrains ou lorsque le nombre de terrains dans le deck est relativement bas.
</p>
<p>
	Une étude détaillée sur {{ mana_dork }}, dont {{ llanowar_elves }} fait partie, est
	{{ disponible }}. Des créatures comme {{ primeval_titan }} et {{ oracle_of_mul_daya }} sont
	cependant à noter comme des sorts de ramp et non des mana dorks.
</p>
<p>
	Certains enchantements permettent également d'augmenter le nombre de manas disponibles. Les
	plus joués sont {{ utopia_sprawl }} et {{ wild_growth }}. Certains decks utilisent également
	{{ fertile_ground }} et {{ overgrowth }}. Ces enchantement fonctionnent très bien avec
	{{ earthcraft }} par exemple.
</p>
<p>
	Enfin, {{ cailloux }} permettent également de ramper. Ils sont disponibles dans presque toutes
	les combinaisons de couleurs. Jouer des cailloux permet d'accentuer des stratégies qui ne
	peuvent pas être développées avec les sorts de ramp présentés ici.
</p>
<div class="tip">
	<h3>Jouer ramp ne se résume pas à jouer {{ grosses_creatures }} </h3>
	<p>
		Les principaux decks utilisant cette mécanique sont des jeux qui ont besoin de cartes pour
		accéder à un plan de jeu <em>unfair</em>. Cela permet de jouer {{ grosses_creatures }} ou
		de jouer un plan de jeu Combo avec {{ maelstrom_wanderer }},
		{{ titania_protector_of_argoth }} ou {{ the_gitrog_monster }}.
	</p>
	<p>
		Une fois le besoin de sorts de ramp confirmé, il faut déterminer le style de ceux-ci.
		Par exemple, {{ the_gitrog_monster }} cherche en priorité à jouer des sorts mettant les
		terrains en jeu dégagés puis à augmenter le nombre de land drop. L'approche de {{ maelstrom_wanderer }} est différente. Ce qui est recherché est
		l'augmentation du nombre de terrains en jeu. Cela revient à jouer en priorité les
		sorts présentés dans le deuxième paragraphe.
	</p>
	<p>
		Sans objectif à accomplir, ces cartes sont assez mauvaises dans un deck. En effet, les
		sorts de ramp se révèlent être de mauvaises pioches en fin de partie.
	</p>
</div>
{% endtrans %}
{% endblock %}
