{% extends "articles/complexite-et-machine-de-turing/_layout.html" %}

{% block title %}
Complexité et Machine de Turing
{% endblock %}

{% block content %}
<h1>{{ _("Complexite et Machine de Turing") }}</h1>
{{ contributor.zombie33() }}

{% trans trimmed %}
<p>
	Le 23 Avril 2019 est sortie une publication mathématique traitant de Magic avec de
	l'algorithmique théorique. Cet article fait suite à cette publication et souhaite  clarifier
	certaines notions et présenter la preuve du résultat d'une manière accessible à tou·te·s.
	L'article abordera les notions de complexité, d'intelligence artificielle et de résolution d'un
	jeu.
</p>
<p>
	Cet article est de taille conséquente ; pour en faciliter la lecture, son contenu a été découpé
	en plusieurs sections :
</p>
{% endtrans %}
<ul>
	<li>
		{{ link("/articles/complexite-et-machine-de-turing/jeu-complexite-et-resolution") }}
	</li>
	<li>
		{{ link("/articles/complexite-et-machine-de-turing/magic-et-complexite") }}
	</li>
	<!--
	<li>
		{{ link("/articles/complexite-et-machine-de-turing/une-machine-de-turing-en-carte-magic") }}
	</li>
	<li>
		{{ link("/articles/complexite-et-machine-de-turing/un-jeu-de-nim-pour-se-detendre") }}
	</li>
	-->
</ul>
{% endblock %}
