:root {
	--tip-background: #F7E3D1;
	--tip-border: #DC8C46;

	--author-background: #D1EEF7;
	--author-border: #46B9DC;

	--color-white: #ffffff;
}

.theme-toggle {
	background: url("/static/img/icons/moon.svg");
	background-size: 24px 24px;
}

svg path {
	fill: var(--dark-color) !important;
	stroke: none;
}
.site-logo svg path {
	fill: var(--dark-color) !important;
	stroke: var(--light-color) !important;
}
.site-logo:hover svg path {
	fill: var(--orange-color) !important;
	stroke: var(--light-color) !important;
}

body {
	color: var(--dark-color);
	background-color: var(--light-color);
}

article h1,
article h2,
article h3,
article h4,
article h5 {
	color: var(--brown-color);
}

a {
	color: var(--dark-color);
}
a:hover,
a:focus {
	color: var(--orange-color);
	border-color: var(--orange-color);
}

tr:hover,
tr.selected {
	background-color: var(--brown-color) !important;
}

.card {
	color: var(--green-color);
}

.tip {
	background: var(--tip-background);
	color: var(--dark-color);
	border: 1px solid var(--tip-border);
}
.tip h3 {
	color: #583410 !important;
}
.tip h3 a {
	color: #583410 !important;
}
.tip h3::before {
	color: #583410;
}

.warning {
	background: var(--warning-light);
	border: 1px solid var(--warning-dark);
	color: var(--dark-color);
}
.warning h3 {
	color: var(--warning-dark) !important;
}
.warning h3 a {
	color: var(--warning-dark) !important;
}
.warning h3::before {
	color: var(--warning-dark);
}

.decklist {
	background-color: var(--decklist-light);
	color: var(--dark-color);
}
.decklist p {
	color: var(--dark-color);
}
.decklist .card {
	color: var(--blue-color);
}
.decklist .card:hover,
.decklist .card:focus {
	color: var(--green-color);
}

.author {
	background: var(--author-background);
	border: 1px solid var(--author-border);
}
