{% extends "layout.html" %}

{% block title %}
Section Archétypes
{% endblock %}

{% block content %}
{% trans trimmed
	deckbuilding=_("deckbuilding (<em>à venir</em>)")
%}
<h1>Archétypes</h1>
<p>
	Cette section complète l'introduction au {{ deckbuilding }} et propose des
	archétypes de tournois qui ont fait leurs preuves dans des tournois d'au
	moins 40 joueurs.
</p>
{% endtrans %}

{{ bootstrap.card("Adeliz, the Cinder Wind", "/archetypes/adeliz-the-cinder-wind", "Tempo") }}
{{ bootstrap.card("Aminatou, the Fateshifter", "/archetypes/aminatou-the-fateshifter", "Prison") }}
{{ bootstrap.card("Isamaru, Hound of Konda", "/archetypes/isamaru-hound-of-konda", "Swarm") }}
{{ bootstrap.card("Golos, Tireless Pilgrim", "/archetypes/golos-tireless-pilgrim", "Midrange Non-Bleu") }}
{{ bootstrap.card("Kelsien, the Plague", "/archetypes/kelsien-the-plague", "Swarm") }}
{{ bootstrap.card("Kess, Dissident Mage", "/archetypes/kess-dissident-mage", "Draw Go") }}
{{ bootstrap.card("Orvar, the All-Form", "/archetypes/orvar-the-allform", "Contrôle-Combo") }}
{{ bootstrap.card("Will Kenrith", "/archetypes/rowan-and-will-kenrith", "Big Spell") }}
{{ bootstrap.card("The Gitrog Monster", "/archetypes/the-gitrog-monster", "Contrôle-Combo") }}
{{ bootstrap.card("Titania, Protector of Argoth", "/archetypes/titania-protector-of-argoth", "Voltron Agro") }}
{{ bootstrap.card("Venser, Shaper Savant", "/archetypes/venser-shaper-savant", "Tempo") }}
{{ bootstrap.card("Winota, Joiner of Forces", "/archetypes/winota-joiner-of-forces", "Voltron Combo") }}

<div class="clear"></div>

{% endblock %}
