{% extends "layout.html" %}
{% import "cartes-thematiques/_layout_card_column.html" as layout with context %}

{% block article %}
<article class="article-columns">
	{% block content %}{% endblock %}
</article>
{% endblock %}
