{% extends "archetypes/_layout.html" %}
{% import "archetypes/_layout_wip.html" as layout with context %}
{% import "archetypes/rowan-and-will-kenrith.json" as deck_json %}

{% block title %}
Rowan and Will Kenrith
{% endblock %}

{% block meta %}
<meta property="decklist" content='{{ deck_json | tojson }}' />
{% endblock %}

{% block archetype_name %}
<h1>Rowan and Will Kenrith</h1>
{{ layout.wip() }}
{% endblock %}

{% block archetype %}
{% endblock %}
