{% extends "layout.html" %}
{% import "cartes-thematiques/_layout_wip.html" as layout with context %}

{% block title %}
La Destruction de permanents
{% endblock %}

{% block content %}
{% trans trimmed %}
<h1>La destruction de permanents</h1>
{% endtrans %}
{{ layout.wip() }}
{% endblock %}
