{% macro zombie33() -%}
<div class="author">
	<!-- <img src="#" alt="zombie33" /> -->
	<p>
		<em>
			{% trans %}
			Jérémy B. alias Zombie33 est joueur de Magic depuis 2002 où il débute avec les fameux
			zombies du bloc Carnage. Il est très impliqué dans la promotion du format Peasant,
			format pour lequel il organise des tournois et a participé pendant plusieurs années à
			la conception de la Ban List. Étant aussi professeur de mathématiques, ses articles
			sont souvent reliés à cette discipline.
			{% endtrans %}
		</em>
	</p>
	<div class="clear"></div>
</div>
{%- endmacro %}
