{% extends "archetypes/_layout.html" %}
{% import "archetypes/_layout_wip.html" as layout with context %}
{% import "archetypes/isamaru-hound-of-konda.json" as deck_json %}

{% block title %}
Isamaru, Hound of Konda
{% endblock %}

{% block meta %}
<meta property="decklist" content='{{ deck_json | tojson }}' />
{% endblock %}

{% block archetype_name %}
<h1>Isamaru, Hound of Konda</h1>
{% endblock %}

{% block archetype %}
{% trans trimmed
	cartes_taxe=link("/cartes-thematiques/mecaniques-de-la-colorpie/les-cartes-de-taxe", _("créatures hatebear")),
	removals=_("cartes de gestion"),
	swaps=_("commandants"),
	stompy=link("/cartes-thematiques/mecaniques-de-la-colorpie/les-grosses-creatures", _("créatures stompy"))
%}
<h2>Présentation rapide</h2>
<p>
	Il s'agit d'un deck consistant en une trentaire de cartes qui créent la colonne vertébrale. Le
	reste des cartes permet de s'assurer une adaptation aux decks attendus lors d'un tournoi ou des
	préférences personnelles. Cela en fait un deck en perpétuelle évolution.
</p>
<p>
	En Duel Commander, c'est ce qui se rapproche le plus du deck Legacy <em>Death and Taxes</em>.
	Les règles de construction du format empêchent cependant le deck d'assumer totalement ce rôle.
	La présence de {{ cartes_taxe }} permet au deck de ralentir le développement de l'adversaire
	tout en laissant la possibilité d'infliger des dégâts à l'adversaire et de clore la partie en
	limitant l'interaction adverse.
</p>
<p>
	Les {{ cartes_taxe }} peuvent ainsi permettre au deck de parfois prendre une posture de deck
	tempo plus défensive et en essayant de grignoter l'adversaire en contournant les menaces
	proposées. Il est également possible pour le deck d'être très agressif avec les cartes les plus
	efficientes en mana jusqu'à faire plier l'adversaire sous la pression.
</p>
<p>
	Dans l'ensemble, le plan de jeu est fait pour avoir l'avantage contre les decks contrôle avec
	des moyens pour contourner ses {{ removals }} avec des cartes comme {{ reverent_mantra }} et
	{{ flawless_maneuver }}. Cela le rend souvent moins linéaire que d'autres agro du format et
	extrêmement plaisant à piloter.
</p>
<p>
	<b>Points positifs</b><br>
	Flexibilité dans la construction du deck et dans le style de jeu ;<br>
	Une variété de {{ swaps }} puissants bien que technique à apprivoiser ;<br>
	Une grande variété de synergies qui surprennent.
</p>
<p>
	<b>Points négatifs</b><br>
	Difficultés à combattre les champs de bataille remplis de {{ stompy }} ;<br>
	Parfois insuffisant contre combo malgré quelques bonnes armes ;<br>
	Les prises de décisions ne sont pas toujours évidentes et ont des conséquences fortes pour la suite de la partie.
</p>
{% endtrans %}
{% endblock %}
