{% macro card_column(name, cat="") -%}
<div class="column" style="max-width:30%">
	<div class="column-image">
		{{ card_image(name) }}
		<h4 style="text-align: center;">{{ name }}</h4>
		{% if cat != "" %}
		<p class="center-subtitle">
			{{ gettext('%(cat)s', cat=cat) }}
		</p>
		{% endif %}
	</div>
	<div class="clear"></div>
</div>
{%- endmacro %}
