{% extends "layout.html" %}

{% block title %}
Les Grosses Créatures
{% endblock %}

{% block content %}
{% trans trimmed
	mana_dork=link("/cartes-thematiques/mecaniques-de-la-colorpie/les-mana-dorks", _("mana dorks")),
	reanimation=link("/cartes-thematiques/mecaniques-de-la-colorpie/la-reanimation-de-creatures", _("réanimation")),
	les_contresorts=link("/cartes-thematiques/mecaniques-de-la-colorpie/les-contresorts"),
	cartes_de_taxe=link("/cartes-thematiques/mecaniques-de-la-colorpie/les-cartes-de-taxe"),

	classification_en_macrotypes=link("/articles/lart-de-classifier-les-decks/classification-en-macrotypes")
%}
<h1>Les grosses créatures</h1>
<p>
	Une grosse créature, <em>fatty</em>, est une créature dont la force et l'endurance dépassent
	strictement 3. C'est l'opposée d'une créature <em>weenie</em> qui a peu de force et
	d'endurance.
</p>
<p>
	Il est possible d'utiliser les grosses créatures pour deux objectifs différents : les créatures
	<em>Stompy</em> sont des grosses créatures très peu chères tandis que les <em>Finisher</em>
	permettent de clore la partie efficacement.
</p>
<p>
	{{ tarmogoyf }} et {{ questing_beast }} sont deux créatures apparentées à la catégorie Stompy.
	Des créatures « anti-contrôle » se retrouvent aussi dans cette catégorie comme
	{{ thrun_the_last_troll }} et {{ shifting_ceratops }} jouées dans plusieurs formats.
	{{ strangleroot_geist }}, grâce à sa capacité <em>Survivance</em>, est l'icône des créatures
	Stompy en Modern.
</p>
<p>
	À mi-chemin entre les créatures Stompy et les créatures Finisher, {{ elder_gargaroth }}
	bénéficie de mot-clés avantageux et d'une capacité très versatile qui permet à cette bête
	d'être jouée pour intervenir dans beaucoup de situations.
</p>
<p>
	{{ primeval_titan }} se rapproche des créatures Finisher car la résolution de ce sort permet de
	développer de manière très rapide son mana et d'enchaîner les fatties pour prendre le contrôle
	du champ de bataille.
</p>
<p>
	Une partie des Finisher est jouée accompagnée de {{ mana_dork }} et de cartes comme
	{{ survival_of_the_fittest }}. L'intérêt est de jouer peu de Finisher et de pouvoir y avoir
	accès dès que c'est nécessaire. Ces Finisher sont souvent des créatures comme
	{{ craterhoof_behemoth }} et {{ kamahl_heart_of_krosa }} qui fournissent un effet
	{{ overrun }}.
</p>
<p>
	D'autres Finisher sont des cibles de choix pour les effets de {{ reanimation }}.
	{{ sidisi_brrod_tyrant }} peut permettre de développer un tel plan de jeu. Les créatures vertes
	à réanimer sont {{ archetype_of_endurance }}, {{ terastodon }} ou encore {{ woodfall_primus }}.
</p>
<div class="tip">
	<h3>Comment assurer l'impact de ses fatties ?</h3>
	<p>
		C'est vraiment important que les fatties soient capables d'arriver sur le champ de bataille
		pour avoir l'occasion de faire ce pour quoi ces cartes ont été choisies. Pour ce faire, il
		faut réussir à résoudre son sort. Parmi les outils disponibles, il existe des cartes qui
		rendent des sort <em>incontrables</em>, c'est-à-dire que {{ les_contresorts }} ne peuvent
		pas faire ce pour quoi ils sont joués.
	</p>
	<p>
		Parmi les cartes jouables qui proposent cela, il y a soit les {{ cartes_de_taxe }}, comme
		{{ defense_grid }} ou {{ thalia_guardian_of_thraben }}, soit les cartes qui permettent de
		rendre des sorts incontrables, comme {{ allosaurus_shepherd }}, {{ destiny_spinner }},
		{{ vexing_shusher }} et {{ prowling_serpopard }} qui sont les plus jouées dans ce but.
	</p>
	<p>
		Il faut ensuite pouvoir profiter de sa créature et pouvoir attaquer avec. Pour cela, des
		cartes comme {{ lightning_greaves }} ou {{ spellskite }} sont envisageables pour éviter les
		<em>spot removals</em>.
	</p>
</div>
{% endtrans %}
{% endblock %}
