{% extends "articles/classifier-un-deck/_layout.html" %}

{% block title %}
Les Catégories de decks
{% endblock %}

{% block content %}
{% trans trimmed
	magic_ville=external("https://www.magic-ville.fr", "Magic-Ville")
%}
<h1>Les Catégories de decks</h1>
<p>
	La classification en archétype permet d'affiner la classification en macrotype. La version la
	plus connue est celle de Patrick Chapin basée sur la classification en 4 macrotypes (système
	<strong>B</strong>).
<p>
	La classification ci-dessous a été réalisée par <strong>Zombie33</strong> pour le site
	{{ magic_ville }} où cet article a été originellement publié. Elle comporte 21 catégories et se
	base sur les travaux de Patrick Chapin. Les archétypes <em>Ramp</em>, <em>Wave Combo</em>,
	<em>Voltron</em>, <em>Créature-Combo</em> et <em>Aggro-Contrôle-Combo</em> sont des ajouts de
	Zombie33.
</p>
{% endtrans %}

<div class="center" style="font-size: 0.8em">
	<table>
		<thead>
			<th></th>
			<th>A</th>
			<th>B</th>
			<th>C</th>
			<th>D</th>
			<th>E</th>
			<th>F</th>
		</thead>
		<tbody>
			{% macro line (archetype, a, b, c, d, e, f) -%}
			<tr>
				<th align="left">{{ archetype }}</th>
				<td>{{ a }}</td>
				<td>{{ b }}</td>
				<td>{{ c }}</td>
				<td>{{ d }}</td>
				<td>{{ e }}</td>
				<td>{{ f }}</td>
			</tr>
			{%- endmacro%}

			{% trans trimmed
				archetype_1 =line("01\xa0—\xa0Swarm","Aggro","Aggro","Aggro","Aggro","Aggro","Aggro"),
				archetype_2 =line("02\xa0—\xa0Red\xa0Aggro","Aggro","Aggro","Aggro","Aggro","Aggro","Aggro"),
				archetype_3 =line("03\xa0—\xa0Aggro\xa0Linéaire","Aggro","Aggro","Aggro","Aggro","Aggro","Aggro"),
				archetype_4 =line("04\xa0—\xa0Suicide","Aggro","Aggro","Aggro","Aggro","Aggro","Aggro"),
				archetype_5 =line("05\xa0—\xa0Tempo","Aggro","Midrange","Tempo","Tempo","Aggro-Contrôle","Tempo"),
				archetype_6 =line("06\xa0—\xa0Rock","Contrôle","Midrange","Midrange","Midrange","Aggro-Contrôle","Midrange"),
				archetype_7 =line("07\xa0—\xa0Pur\xa0Midrange","Contrôle","Midrange","Midrange","Midrange","Aggro-Contrôle","Midrange"),
				archetype_8 =line("08\xa0—\xa0Midrange\xa0Non\u2011Bleu","Contrôle","Midrange","Midrange","Midrange","Aggro-Contrôle","Midrange"),
				archetype_9 =line("09\xa0—\xa0Draw\xa0Go","Contrôle","Contrôle","Contrôle","Contrôle","Contrôle","Contrôle"),
				archetype_10=line("10\xa0—\xa0Tapout","Contrôle","Contrôle","Contrôle","Contrôle","Contrôle","Contrôle"),
				archetype_11=line("11\xa0—\xa0Prison","Contrôle","Contrôle","Contrôle","Contrôle","Contrôle","Contrôle"),
				archetype_12=line("12\xa0—\xa0Contrôle\u2011Combo\xa0Pur","Contrôle","Contrôle","Contrôle","Contrôle","Contrôle\u2011Combo","Contrôle\u2011Combo"),
				archetype_13=line("13\xa0—\xa0Ramp","Contrôle","Contrôle","Contrôle","Ramp","Contrôle","Contrôle"),
				archetype_14=line("14\xa0—\xa0Big\xa0Spell","Combo","Combo","Combo","Combo","Combo","Combo"),
				archetype_15=line("15\xa0—\xa0Combo\xa0Storm","Combo","Combo","Combo","Combo","Combo","Combo"),
				archetype_16=line("16\xa0—\xa0Combo\xa0Traditionnel","Combo","Combo","Combo","Combo","Combo","Combo"),
				archetype_17=line("17\xa0—\xa0Lava\xa0Spike","Aggro","Combo\u002FAggro","Combo\u002FAggro","Combo\u002FAggro","Combo","Combo"),
				archetype_18=line("18\xa0—\xa0Wave\xa0Combo","Combo\u002FAggro","Combo\u002FAggro","Combo\u002FAggro","Combo\u002FAggro","Aggro\u2011Combo","Aggro\u2011Combo"),
				archetype_19=line("19\xa0—\xa0Voltron","Aggro","Aggro","Aggro","Aggro","Aggro\u2011Combo","Aggro\u2011Combo"),
				archetype_20=line("20\xa0—\xa0Créature\xa0Combo","Combo","Combo","Combo","Combo","Aggro\u2011Combo","Aggro\u2011Combo"),
				archetype_21=line("21\xa0—\xa0Aggro\u2011Contrôle\u2011Combo","-","-","-","-","-","A\u2011C\u2011C")
			%}
			{{ archetype_1 }}
			{{ archetype_2 }}
			{{ archetype_3 }}
			{{ archetype_4 }}
			{{ archetype_5 }}
			{{ archetype_6 }}
			{{ archetype_7 }}
			{{ archetype_8 }}
			{{ archetype_9 }}
			{{ archetype_10 }}
			{{ archetype_11 }}
			{{ archetype_12 }}
			{{ archetype_13 }}
			{{ archetype_14 }}
			{{ archetype_15 }}
			{{ archetype_16 }}
			{{ archetype_17 }}
			{{ archetype_18 }}
			{{ archetype_19 }}
			{{ archetype_20 }}
			{{ archetype_21 }}
			{% endtrans %}
		</tbody>
	</table>
</div>
<p>
	{% trans %}
	Le tableau ci-dessus donne la liste les 21 catégories et la manière de les classer dans les
	macrotypes vu précédemment. Les paragraphes ci-dessous présentent en détail chacunes des
	catégories.
	{% endtrans %}
</p>
<ol style="padding-left:1em;">
	<li>
		{% trans trimmed
			ci_thalia_guardian='<span class=image>%(card)s</span>'|format(card=card_image("Thalia, Guardian of Thraben"))|safe,
			aether_vial=card("Æther Vial")
		%}
		<p>
			<strong>Swarm</strong> :
		</p>
		{{ ci_thalia_guardian }}
		<p>
			Catégorie de deck Aggro qui se caractérise par :
		</p>
		<ul>
			<li>
				Gagne par l'accumulation de petites créatures ;
			</li>
			<li>
				Gagne généralement le combat en débordant l'adversaire avec les créatures plutôt
				qu'en essayant de tuer les créatures adverses ;
			</li>
			<li>
				Gagne en misant sur l'accumulation de créatures sans synergie particulière entre
				elles (en partageant un type par exemple).
			</li>
		</ul>
		<p>
			Les principaux représentants de cette catégorie sont les decks <em>Weenie White</em>.
			Dans les formats éternels, comme le Modern ou le Legacy, ces créatures sont choisies
			pour gêner le développement adverse, voire le contrecarrer (ces créatures sont nommées
			<em>hatebear</em>). Ceci n'est toutefois pas une caractéristique générale des decks
			Swarm : la volonté principale reste d'envahir le champ de bataille
			(avec l'aide de {{ aether_vial }} en Modern et en Legacy).
		</p>
		<p>
			Si l'accumulation de créatures sur le champ de bataille est issue d'une combo ou si
			cette accumulation est susceptible de s'emballer à cause d'interactions ou de combos,
			le deck rentrera alors dans la catégorie Créature-Combo. Ces decks
			sont présentés plus tard et sont en général moins agressifs.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_goblin_chainwhirler='<span class=image>%(card)s</span>'|format(card=card_image("Goblin Chainwhirler"))|safe,
			giant_growth=card("Giant Growth")
		%}
		<p>
			<strong>Red Aggro</strong> :
		</p>
		{{ ci_goblin_chainwhirler }}
		<p>
			Catégorie de deck Aggro se caractérisant par :
		</p>
		<ul>
			<li>
				Une courbe plus basse qui permet au deck de prendre l'ascendant sur l'adversaire
				dans les premiers tours ;
			</li>
			<li>
				La possibilité de clore une partie avec des sorts de dégâts directs
				(des <em>blasts</em>) ;
			</li>
			<li>
				Le besoin de se débarraser des bloqueurs adverses à l'aide des blasts se trouve en
				directe opposition avec la possiblité de cibler directement l'adversaire
			</li>
		</ul>
		<p>
			Bien qu'on parle de Red Aggro, la couleur rouge n'est absolument pas une nécessité pour
			aire partie de cette catégorie. Les decks <em>Mono Green Stompy</em> en sont d'ailleurs
			un bon exemple car les boosts, comme {{ giant_growth }}, ciblant des créatures avec
			capacités d'évasion ou des créatures bloquées remplacent le rôle des blasts. Les decks
			de cette catégorie font partie de ces decks plutôt simples à construire et relativement
			efficaces dans la plupart des formats.
		</p>
		<p>
			En fonction du ratio entre les sorts de dégâts directs et les sorts de créatures dans
			le deck, le nom du deck change : RDW / Sligh / Burn (voir la catégorie Lava Spike pour
			ce dernier). Souvent confondus, les decks RDW se distinguent pourtant notablement des
			decks Gobelins par leur absence ou quasi-absence de synergies "tribales".
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_cavern_of_souls='<span class=image>%(card)s</span>'|format(card=card_image("Cavern of Souls"))|safe,
			cavern_of_souls=card("Cavern of Souls"),
			champion_of_the_parish=card("Champion of the Parish"),
			rebel_1999_block_deck=external("https://www.mtgtop8.com/event?e=9167&d=252441&f=BL", "deck bloc Rebel de 1999"),
			rick_stout_uw_human=external("https://www.mtgtop8.com/event?e=2732&d=217663&f=ST","UW Human de Rick Stout")
		%}
		<p>
			<strong>Aggro Linéaire</strong> :
		</p>
		{{ ci_cavern_of_souls }}
		<p>
			Catégorie de deck Aggro qui se caractérise par :
		</p>
		<ul>
			<li>
				Les cartes sont exclusivement basées sur un thème commun, les créatures ont
				généralement le même type ;
			</li>
			<li>
				Le deck utilise des synergies entre les cartes liées à ce thème commun.
			</li>
		</ul>
		<p>
			Beaucoup de decks Aggro Linéaire sont des decks tribaux, le thème commun étant un type
			de créature mais ce n'est toutefois pas une généralité. On retrouve aussi les decks
			<em>Affinity</em> et <em>Tempered Steel</em> dans cette catégorie dont le thème commun
			est ici « Artefact ». De plus, tous les decks tribaux ne sont pas des Aggro Linéaire,
			en effet <em>Faeries</em> est par exemple un deck Tempo et <em>Elfball</em> un deck
			Storm Combo.
		</p>
		<p>
			Les deck Aggro Linéaire sont extrêmement populaires dans tous les formats et toutes les
			extensions récentes de Magic sont construites pour que cette catégorie de deck soit
			présente en limité. Le premier archétype à rentrer dans cette catégorie fut le
			{{ rebel_1999_block_deck }}
		</p>
		<p>
			Il en faut parfois peu pour qu'un deck intègre cette catégorie. C'est par exemple le
			cas du deck standard {{ rick_stout_uw_human }} qui se distingua des autres listes
			UW par l'ajout de {{ cavern_of_souls }} et {{ champion_of_the_parish }} qui intégrait
			parfaitement à ce deck tribal.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_carnophage='<span class=image>%(card)s</span>'|format(card=card_image("Carnophage"))|safe,
			black_suicide_1999_brian_schneider_extended_deck=external("https://www.mtggoldfish.com/deck/407304#paper","deck Extended Black Suicide de Brian Schneider (1999)"),
			ancient_tomb=card("Ancient Tomb"),
			chrome_mox=card("Chrome Mox"),
			simian_spirit_guide=card("Simian Spirit Guide")
		%}
		<p>
			<strong>Suicide</strong>
		</p>
		{{ ci_carnophage }}
		<p>
			Catégorie de deck Aggro (appelée <em>Fish</em> par Patrick Chapin) et se caractérisant
			par :
		</p>
		<ul>
			<li>
				Des accélérateurs de mana en vue de poser le plus vite possible des créatures pour
				mettre la pression sur l'adversaire ;
			</li>
			<li>
				Des sorts de gestions qui empêchent l'adversaire de répondre aux menaces posées
				dans les premiers tours.
			</li>
		</ul>
		<p>
			L'appellation Suicide vient du fait que le deck à tendance à jouer des cartes qui vont
			l'affecter de manière néfaste. Certaines cartes peuvent nécessiter, par exemple, une
			perte de point de vie, un sacrifice de permanent ou encore de faire du <em>Card
			Disadvantage</em> (CD), comme les accélérateurs de mana éphémères extrêmement courant
			dans ces decks. Un des premiers deck de cette catégorie fut le
			{{ black_suicide_1999_brian_schneider_extended_deck }}.
		</p>
		<p>
			On classe également dans cette catégorie le deck <em>Dragon Stompy</em> dans lequel on
			retrouve le besoin de mana dans les premiers tours via {{ simian_spirit_guide}},
			{{ chrome_mox }} et {{ ancient_tomb }} pour mettre en place un léthal rapide et une
			carte qui va empêcher le développement adverse. Le deck mise sur cette impulsion qu'il
			aura mis sur le début de partie et pour laquelle il a dû faire énormément de CD.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_delver_of_secrets='<span class=image>%(card)s</span>'|format(card=card_image("Delver of Secrets"))|safe
		%}
		<p>
			<strong>Tempo</strong> :
		</p>
		{{ ci_delver_of_secrets }}
		<p>
			Catégorie de deck Aggro-Contrôle, parfois assimilée aux decks Aggro et parfois
			considérée comme un macrotype à part entière. Les decks Tempo basent leur stratégie sur
			le fait de toujours vouloir conserver un meilleur tempo que celui de l'adversaire à
			l'aide de sorts peu cher. On parle aussi de <em>Disruptive Aggro</em> pour désigner
			cette famille de deck.
		</p>
		<p>
			Les decks Tempo sont connus pour jouer le rôle de l’agresseur contre Contrôle et le
			rôle du défenseur contre Aggro.
		</p>
		<p>
			Les principales faiblesses des decks Tempo sont qu'ils ne produisent pas de
			<em>Card Advantage</em> et que leur stratégie s'épuise sur le long terme. De plus,
			s'ils perdent leur avantage, il leur est difficile de reprendre l'ascendant sur la
			partie. Malgré cela, des decks reconnus comme étant les meilleurs decks de leur format
			appartiennent à cette catégorie.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_abrupt_decay='<span class=image>%(card)s</span>'|format(card=card_image("Abrupt Decay"))|safe,
			deranged_hermit=card("Deranged Hermit"),
			phyrexian_plaguelord=card("Phyrexian Plaguelord")
		%}
		<p>
			<strong>Rock</strong> :
		</p>
		{{ ci_abrupt_decay }}
		<p>
			Catégorie de deck Midrange qui se caractérise par :
		</p>
		<ul>
			<li>
				Des créatures généralement un peu plus grosses qu'Aggro classique ;
			</li>
			<li>
				De l'accélération de mana et de la disruption ;
			</li>
			<li>
				Du vert pour les créatures et du noir pour la défausse et les removal.
			</li>
		</ul>
		<p>
			Cette catégorie de deck vient d'un deck nommé par Malka un fan de catch : "The Rock and
			His Millions" où "The Rock" en hommage à Dwayne The Rock Johnson correspondait à la
			carte {{ phyrexian_plaguelord }} et "His Millions" correspondaient aux écureuils crées
			par {{ deranged_hermit }}. On peut distinguer principalement deux types de decks Rock :
		</p>
		<ul>
			<li>
				Les decks plus orientés Contrôle qui se focalisent plutôt sur un
				<em>Card Advantage</em> progressif. Ces decks essentiellement B/G ont tendance à
				jouer le rôle du Contrôle même contre d'autres decks Contrôle ;
			</li>
			<li>
				Les decks Rock plus Aggro qui se focalisent davantage sur la solidité de ses
				créatures que sur le Card Advantage. Ces decks correspondent essentiellement aux
				decks Junk (Abzan W/B/G).
			</li>
		</ul>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_knight_of_the_reliquary='<span class=image>%(card)s</span>'|format(card=card_image("Knight of the Reliquary"))|safe
		%}
		<p>
			<strong>Midrange Pur</strong> :
		</p>
		{{ ci_knight_of_the_reliquary }}
		<p>
			Catégorie de deck Midrange qui se caractérise par :
		</p>
		<ul>
			<li>
				La qualité intrinsèque des cartes plutôt que les synergies entre elles ;
			</li>
			<li>
				Des créatures polyvalentes et des <em>removals</em> peu cher ;
			</li>
			<li>
				La possibilité de s'adapter à n'importe quel environnement.
			</li>
		</ul>
		<p>
			Les decks Pure Midrange sont parfois appelé <em>Good Stuff</em> car ils ont tendance à
			incorporer les meilleurs sorts du format, les removals les moins chers ainsi que les
			meilleures créatures pour chaque coût converti de mana. Cette configuration force bien
			souvent ces decks à jouer tricolore, voire quadricolore si la base de mana le permet.
		</p>
		<p>
			Les decks Pure Midrange sont des decks relativement faciles et rapides à construire une
			fois que sont identifiées les meilleurs cartes à disposition dans un format. Ils font
			donc très régulièrement partie des premiers decks à apparaître avec notamment les Aggro
			Linéaire et les Red Aggro. Ces decks ont aussi tendance à être mauvais contre les decks
			<em>unfair</em> et excellents contre les decks <em>fair</em>. C'est pourquoi dans un
			format résolu, lorsqu'un deck Midrange est capable d'incorporer au moins un sort unfair
			tel que de la destruction massive de terrain, il peut faire d'excellent résultats.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_gray_merchant='<span class=image>%(card)s</span>'|format(card=card_image("Gray Merchant of Asphodel"))|safe,
			mono_black_control=external("https://www.mtgtop8.com/event?e=9201&d=252718&f=BL","Mono Black Control"),
			astral_slide=external("https://www.mtgtop8.com/event?e=9207&d=252771&f=BL","Astral Slide"),
			life_from_the_loam=card("Life from the Loam")
		%}
		<p>
			<strong>Midrange Non-Bleu</strong> :
		</p>
		{{ ci_gray_merchant }}
		<p>
			Catégorie de deck Midrange qui se caractérise par :
		</p>
		<ul>
			<li>
				De la gestion presque totalement dirigée contre les créatures adverses ;
			</li>
			<li>
				La présence d'un <em>moteur de pioche</em> (ou de <em>Card Advantage</em>)
				quelconque dont le deck est assez dépendant.
			</li>
		</ul>
		<p>
			Bien que la majorité des decks de cette catégorie n'utilisent pas de mana bleu, ce
			n'est pas une condition nécessaire pour faire partie de cette catégorie. Les decks Non-
			Bleu sont globalement rares dans les formats eternels (voire absents du Legacy et du
			Vintage) car ils ne sont généralement pas assez polyvalents pour s'y imposer. Les decks
			Bloc {{ mono_black_control }} de 2002 et {{ astral_slide }} de 2003 font partie des
			permiers decks de cette catégorie.
		</p>
		<div class="clear"></div>
		<div class="tip">
			<h3>Le cas de {{ life_from_the_loam }}</h3>
			<p>
				Cette catégorie permet d'aborder le cas de {{ life_from_the_loam }} présente dans
				des decks appartenant à des catégories diverses. L'un de ces decks, la version
				Aggro Loam de l'Extended que l'on retrouve aussi en Modern, vérifie justement les
				critères du deck Midrange Non-Bleu, {{ life_from_the_loam }} jouant ici le rôle du
				moteur de CA dont le deck est assez dépendant.
			</p>
		</div>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_cryptic_command='<span class=image>%(card)s</span>'|format(card=card_image("Cryptic Command"))|safe
		%}
		<p>
			<strong>Draw Go</strong> :
		</p>
		{{ ci_cryptic_command }}
		<p>
			Catégorie de deck Contrôle qui se caractérise par :
		</p>
		<ul>
			<li>
				Une grande quantité de contresorts pour interagir au maximum contre les
				actions adverses ;
			</li>
			<li>
				Un moteur à <em>Card Advantage</em> pour compenser l'épuisement des contresorts ;
			</li>
			<li>
				La présence de <em>mass removals</em> pour gérer l'ensemble des cartes qui ont pu
				se résoudre.
			</li>
		</ul>
		<p>
			Le terme Draw Go est une allusion aux tours rapides d'un joueur de cet archétype « My
			Turn, Draw, Go ! ». Ces decks se distinguent donc radicalement des decks Tapout vus
			précédemment.
		</p>
		<p>
			Les decks Draw Go ont tendance à faire du <em>un pour un</em> avec leurs contresorts.
			Ils sont naturellement désavantagés contre les decks Aggro qui jouent moins de terrains
			et donc piocheront plus de menaces que Draw Go pourra piocher de réponses. Pour
			contrebalancer cela, les decks Draw Go sont obligés de compenser avec du
			<em>Card Advantage</em>.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_karn_liberated='<span class=image>%(card)s</span>'|format(card=card_image("Karn Liberated"))|safe
		%}
		<p>
			<strong>Tapout</strong> :
		</p>
		{{ ci_karn_liberated }}
		<p>
			Catégorie de deck Contrôle qui se caractérise par :
		</p>
		<ul>
			<li>
				Des <em>mass removal</em> et des sorts visant à empêcher l'adversaire de jouer dans
				le but d'acheter du temps ;
			</li>
			<li>
				Des sorts agressifs pour profiter au maximum du temps acheté.
			</li>
		</ul>
		<p>
			Les decks Tapout jouent essentiellement à leur propre tour et ne gardent donc
			généralement pas de manas disponibles lorsqu'ils ont fini de jouer. L'absence de
			contresort dans un deck Contrôle est généralement un bon moyen de repérer si un deck
			est un Tapout.
		</p>
		<p>
			La première vraie apparition de Tapout en tournoi date de 1997 avec le deck standard
			Big Blue de Erik Lauer.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_stasis='<span class=image>%(card)s</span>'|format(card=card_image("Stasis"))|safe,
			icy_manipulator=card("Icy Manipulator")
		%}
		<p>
			<strong>Prison</strong> :
		</p>
		{{ ci_stasis }}
		<p>
			Catégorie de deck Contrôle qui se caractérise par :
		</p>
		<ul>
			<li>
				La volonté de garder le champ de bataille sous contrôle plutôt que de lui opposer
				des menaces ;
			</li>
			<li>
				Utilise ses sorts permissifs avant tout pour protéger sa propre stratégie ;
			</li>
			<li>
				Une fin de partie où l'adversaire est privé d’interactions.
			</li>
		</ul>
		<p>
			Les decks Prison (aussi appelé Lock), comme les decks Tapout, ont tendance à utiliser
			leur mana de manière proactive. Toutefois, là où un deck Tapout va engager tout son mana
			pour poser une créature qui va dissuader son adversaire d'attaquer, un deck Prison
			préférera prévenir l'attaque, par exemple avec un {{ icy_manipulator }}.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_crop_rotation='<span class=image>%(card)s</span>'|format(card=card_image("Crop Rotation"))|safe,
			muddle_the_mixture=card("Muddle the Mixture"),
			thopter_foundry=card("Thopter Foundry"),
			sword_of_the_meek=card("Sword of the Meek"),
			counterspell=card("Counterspell"),
			bring_to_light=card("Bring to Light"),
			scapeshift=card("Scapeshift"),
			damnation=card("Damnation"),
			crop_rotation=card("Crop Rotation"),
			dark_depths=card("Dark Depths"),
			thespians_stage=card("Thespian's Stage"),
			glacial_chasm=card("Glacial Chasm")
		%}
		<p>
			<strong>Contrôle-Combo Pur</strong> :
		</p>
		{{ ci_crop_rotation }}
		<p>
			Catégorie de deck Contrôle qui se caractérise par :
		</p>
		<ul>
			<li>
				Un jeu entre Draw Go et Tapout avec une victoire issue d'une combo ;
			</li>
			<li>
				Une stratégie lente mais qui peut éventuellement menacer de gagner très tôt dans la
				partie ;
			</li>
			<li>
				De nombreux sorts de gestion et/ou de contresorts.
			</li>
		</ul>
		<p>
			Contrairement à la majorité des decks Combo, les decks de cette famille peuvent faire
			du <em>Card Advantage</em> plutôt que de simplement creuser ou tutoriser les éléments
			de leur combo. On retrouve très souvent dans ces decks un questionnement sur la méthode
			à utiliser pour atteindre sa combo ou au contraire de contrôler le board si cela
			devient nécessaire. Voici quelques exemples :
		</p>
		<ul>
			<li>
				{{ muddle_the_mixture }} → {{ thopter_foundry }} / {{ sword_of_the_meek }}
				(Combo Kill) ou {{ counterspell }}.
			</li>
			<li>
				{{ bring_to_light }} → {{ scapeshift }} (Combo Kill) ou {{ damnation }}.
			</li>
			<li>
				{{ crop_rotation }} → {{ dark_depths }} / {{ thespians_stage }}
				(Combo Kill) ou {{ glacial_chasm }}
			</li>
		</ul>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_primeval_titan='<span class=image>%(card)s</span>'|format(card=card_image("Primeval Titan"))|safe
		%}
		<p>
			<strong>Ramp</strong> :
		</p>
		{{ ci_primeval_titan }}
		<p>
			Catégorie de deck Contrôle qui se caractérise par :
		</p>
		<ul>
			<li>
				La présence de nombreuses cartes productrices de mana et/ou de cartes permettant de
				mettre sur le champ de bataille plus d'un terrain par tour ;
			</li>
			<li>
				La présence de cartes variées ayant un coût de mana élevé qui sont censées être
				jouées en <em>mid game</em>.
			</li>
		</ul>
		<p>
			Il ne faut pas confondre les decks Ramp avec les decks de la catégorie Big Spell bien
			que ceux-ci peuvent aussi avoir une optique Ramp en début de partie.
		</p>
		<p>
			Lorsqu'ils sont bien construits et qu'ils contiennent des sorts adaptés aux decks
			présents dans l'environnement de tournoi, les decks Ramp peuvent être redoutables. Ils
			sont faciles à piloter et ont une grande solidité sur le long terme. S'ils ne tuent pas
			dans le début de partie, ils ont toujours un plan B.
		</p>
		<p>
			Toutefois, si leur accélération de mana est sabotée, les decks Ramp sont terriblement
			ralentis dans leur stratégie et restent souvent au point mort. Ils ont globalement les
			mêmes problèmes que Midrange contre Contrôle et Tempo : s'ils sont pris de vitesse, ils
			doivent subir les sorts de gestion adverses.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_living_end='<span class=image>%(card)s</span>'|format(card=card_image("Living End"))|safe,
			scapeshift=card("Scapeshift"),
			valakut=card("Valakut, the Molten Pinnacle"),
			prismatic_omen=card("Prismatic Omen")
		%}
		<p>
			<strong>Big Spell</strong> :
		</p>
		<p>
			Catégorie de deck Combo qui se caractérise par :
		</p>
		{{ ci_living_end }}
		<ul>
			<li>
				La présence d'un kill (le <em>big spell</em>) dont l'efficacité est dû
				essentiellement au fait que tout le deck soit construit autour et pour maximiser
				l'effet de cette carte.
			</li>
			<li>
				La résolution de ce <em>big spell</em> entraîne une victoire immédiate ou change
				radicalement la dynamique de la partie.
			</li>
		</ul>
		<p>
			Un aspect Ramp est généralement présent dans les decks Big Spell, mais contrairement
			aux decks Ramp, ces decks sont construits autour d'une carte en particulier. De plus
			l'aspect Ramp n'est absolument pas une caractéristique générale de cette catégorie,
			Living End est justement un exemple de deck Big Spell sans aucun aspect ramp.
		</p>
		<div class="clear"></div>
		<div class="tip">
			<h3>Le duo {{ scapeshift }} et {{ valakut }}</h3>
			<p>
				Ce duo de cartes a donné son nom à de nombreux archétypes et tous ces archétypes ne
				correspondent pas aux même catégories.
			<ul>
				<li>
					La version Standard de Valakut est un deck Ramp qui se contente de jouer Valakut
					pour rentabiliser son aspect ramp sur le long terme, quitte à en faire son kill.
					Ici pas de Scapeshift.
				</li>
				<li>
					Le deck Modern Scapeshift est un deck Contrôle-Combo Pur avec de nombreux sorts
					de gestions et contresorts pour temporiser et qui en fin de partie menace de
					tuer à tout moment en jouant Scapeshift.
				</li>
				<li>
					Le deck Modern Valakut, quant à lui, est bien un deck Big Spell où tout le deck
					est construit autour d'un plan de jeu simpliste qui se résume à avoir le plus
					vite possible suffisamment de terrains en jeu et jouer son Big Spell :
					Scapeshift.
				</li>
				<li>
					Enfin la version Omen Scapeshift se distingue foncièrement des autres par sa
					quasi-absence de montagne et donc à la nécessité d'avoir {{ prismatic_omen}}
					sur le champ de bataille avant de lancer scapeshift ce qui fait du deck un
					Combo Traditionnel.
				</li>
			</ul>
		</div>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_grapeshot='<span class=image>%(card)s</span>'|format(card=card_image("Grapeshot"))|safe
		%}
		<p>
			<strong>Combo Storm</strong> :
		</p>
		{{ ci_grapeshot }}
		<p>
			Catégorie de deck Combo qui se caractérise par :
		</p>
		<ul>
			<li>
				L'accumulation des sorts et actions faites lors d'un même tour ;
			</li>
			<li>
				L'absence de sorts spécifique, voire de séquence, pour gagner ;
			</li>
			<li>
				Le besoin de quantité d'actions plus que de leur qualité.
			</li>
		</ul>
		<p>
			Les decks Storm Combo ont un <em>big turn</em> à l'issue duquel l'adversaire est
			défait. Le nom de cette catégorie est tirée de la capacité <em>Storm</em>. Tous les
			decks avec une carte Storm en guise de kill appartiennent à cette catégorie. Ce ne sont
			pas les seuls, High Tide ou KCI font aussi partie de cette catégorie.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_painter_servant='<span class=image>%(card)s</span>'|format(card=card_image("Painter's Servant"))|safe,
			griselbrand=card("Griselbrand"),
			show_and_tell=card("Show and Tell"),
			sneak_attack=card("Sneak Attack")
		%}
		<p>
			<strong>Combo Traditionnel</strong> :
		</p>
		{{ ci_painter_servant }}
		<p>
			Catégorie de deck Combo qui se caractérise par :
		</p>
		<ul>
			<li>
				Une condition de victoire basée directement ou indirectement sur une combo formée de
				deux ou trois cartes ;
			</li>
			<li>
				Des cartes permettant d'aller chercher les éléments de la combo.
			</li>
		</ul>
		<p>
			Les stratégies des Combo Traditionnel peuvent être très variées. On peut en distinguer
			deux variantes :
		</p>
		<ul>
			<li>
				Les decks qui vont avoir tendance à chercher dans leur bibliothèque les éléments de
				la combo ;
			</li>
			<li>
				Les decks qui vont miser sur la redondance des éléments de la combo quitte à jouer
				parfois plusieurs combos différentes.
			</li>
		</ul>
		<p>
			Dans cette seconde variante, on peut citer les decks Reanimator ou, en Legacy, les
			decks {{ show_and_tell }} qui incorporent aussi {{ sneak_attack }}.
		</p>
		<div class="clear"></div>
		<div class="tip">
			<h3>Le plan de jeu Reanimator</h3>
			<p>
				Une fois réanimé, {{ griselbrand }} à tendance à transformer le plan de jeu
				Reanimator en quelque chose proche d'un Storm Combo mais le plan de jeu originel du
				deck correspond bien à la catégorie Combo Traditionnel.
			</p>
		</div>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_lava_spike='<span class=image>%(card)s</span>'|format(card=card_image("Lava Spike"))|safe
		%}
		<p>
			<strong>Lava Spike</strong> :
		</p>
		{{ ci_lava_spike }}
		<p>
			Catégorie de deck Aggro-Combo qui se caractérise par :
		</p>
		<ul>
			<li>
				Une absence d'interactivité avec l'adversaire ;
			</li>
			<li>
				Une stratégie qui consiste à cibler avec ses sorts directement l'adversaire.
			</li>
		</ul>
		<p>
			On retrouve dans cette catégorie principalement deux sortes de deck : <em>Burn</em> et
			<em>Meule</em> :
		</p>
		<ul>
			<li>
				Les decks <em>Burn</em> utilisent leurs sorts pour infliger directement des dégâts à
				l'adversaire. Ils sont présents dans tous les formats. Ils sont tous à dominante
				rouge, mais tous ne sont pas nécessairement monocolores ;
			</li>
			<li>
				Les decks <em>Meule</em> utilisent leurs sorts pour mettre les cartes de la
				bibliothèque de l'adversaire dans son cimetière. Ils sont absent des formats
				éternels et correspondent pour la plupart au plan de jeu de certains decks limités
				bleus.
			</li>
		</ul>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_bloodghast='<span class=image>%(card)s</span>'|format(card=card_image("Bloodghast"))|safe,
			hollow_one=card("Hollow One")
		%}
		<p>
			<strong>Wave Combo</strong> :
		</p>
		{{ ci_bloodghast }}
		<p>
			Catégorie de deck Aggro-Combo qui se caractérise par :
		</p>
		<ul>
			<li>
				Une construction autour d'une mécanique avec des cartes très synergiques entre
				elles ;
			</li>
			<li>
				Une stratégie qui peut menacer extrêmement rapidement l'adversaire et se répéter
				par vagues successives sur le long terme ;
			</li>
			<li>
				Une absence de réel Big Turn.
			</li>
		</ul>
		<p>
			Les principaux decks Wave Combo sont construits autour d'une mécanique dont ils abusent
			des effets. Les deux decks principaux de cette catégorie sont Dredge qui abuse de la
			capacité éponyme et des synergies avec le cimetière et {{ hollow_one }} basé quant à
			lui sur les effets de défausses.
		</p>
		<p>
			Cette catégorie a finalement connu très peu de représentants et il est compliqué d'en
			lister des caractéristiques arrêtées. Toutefois, les deux decks cités ont la
			particularité d'être relativement imprévisibles dans leur sortie même pour leur pilote.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_glistener_elf='<span class=image>%(card)s</span>'|format(card=card_image("Glistener Elf"))|safe,
			kiln_fiend=card("Kiln Fiend"),
			berserk=card("Berserk"),
			temur_battle_rage=card("Temur Battle Rage"),
			zur_the_enchanter=card("Zur the Enchanter"),
			jenara_asura_of_war=card("Jenara, Asura of War")
		%}
		<p>
			<strong>Voltron</strong> :
		</p>
		{{ ci_glistener_elf }}
		<p>
			Catégorie de deck Aggro-Combo qui se caractérise par :
		</p>
		<ul>
			<li>
				Une condition de victoire basée sur le fait d'attaquer avec des créatures
				(généralement une seule) pour tuer en peu de phase d'attaque (parfois une seule) ;
			</li>
			<li>
				Un rythme de jeu plus rapide que les decks Aggro classiques.
			</li>
		</ul>
		<p>
			Les decks Voltron empruntent certaines caractéristiques aux catégories Combo
			Traditionnel et Storm Combo. Un deck emblématique de cette catégorie est
			{{ kiln_fiend }} :
		</p>
		<ul>
			<li>
				Il s'agit d'une combo deux cartes avec {{ berserk }} ou {{ temur_battle_rage }}, ce
				qui donne le côté Combo Traditionnel ;
			</li>
			<li>
				Toutefois, le deck n'a pas besoin de cette seconde carte pour gagner et peut
				remporter la victoire simplement par l'accumulation de sorts joué lors d'un même
				tour, ce qui donne l'aspect Storm Combo.
			</li>
		</ul>
		<p>
			On retrouve aussi dans cette catégorie les decks hexproof qui se basent sur une
			créature qui grossit jusqu'à devenir létale.
		</p>
		<div class="clear"></div>
		<div class="tip">
			<h3>L'origine de Voltron</h3>
			<p>
				Le nom Voltron est issu du Commander pour désigner originellement des decks dont la
				stratégie est entièrement basé sur leur général. Mateus Nogueira distingue dans sa
				classification en catégorie pour le commander les decks Voltron Control (tels que
				{{ zur_the_enchanter}}) des decks Voltron Aggro (tels que
				{{ jenara_asura_of_war }}), focalisés sur le fait de finir rapidement une partie
				via les blessures de général.
			</p>
		</div>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_vizier_of_remedies='<span class=image>%(card)s</span>'|format(card=card_image("Vizier of Remedies"))|safe,
			birthing_pod=card("Birthing Pod"),
			living_end=card("Living End"),
			balustrade_spy=card("Balustrade Spy")
		%}
		<p>
			<strong>Créature Combo</strong> :
		</p>
		<p>
			Catégorie de deck Aggro-Combo qui se caractérise par :
		</p>
		{{ ci_vizier_of_remedies }}
		<ul>
			<li>
				La présence d'un grand nombre de créatures ;
			</li>
			<li>
				Une condition de victoire non-intéractive générée par une combo composée le plus
				souvent de créatures ;
			</li>
			<li>
				Une condition de victoire secondaire consistant à gagner en attaquant avec ses
				créatures (souvent en débordant son adversaire) ;
			</li>
		</ul>
		<p>
			Les decks Combo Créature sont des hybrides entre les decks appartenant aux familles
			Combo Traditionnel et Swarm ce qui en fait naturellement des decks Aggro-Combo.
		</p>
		<div class="clear"></div>
		<div class="tip">
			<h3>Le cas de {{ birthing_pod }}</h3>
			<p>
				Cette catégorie permet d'aborder plus en détail le cas de {{ birthing_pod }}
				présente essentiellement dans deux types de jeu :
			</p>
			<ul>
				<li>
					Les decks ayant une structure de Midrange dont beaucoup de créatures sont jouées
					seulement en un exemplaire pour leur synergie avec Pod dans le but de construire
					diverses séquences d'actions en abusant des effets d'arrivée et de départ du
					champ de bataille. Ces decks là sont classés dans la catégorie Midrange Non-
					Bleu.
				</li>
				<li>
					Les decks basés sur une multitude de créature qui incorpore une combo qui est
					la principale condition de victoire du deck. Le rôle de {{ birthing_pod }} est
					d'assembler une combo même s'il est également possible tutoriser des solutions
					face à des problèmes spécifiques. Ces decks appartiennent à la catégorie Combo
					Créature.
				</li>
			</ul>
			<p>
				{{ birthing_pod }} pourrait être classée dans la catégorie Big Spell car les decks
				sont basés essentiellement autour de cette carte mais cette carte est avant tout un
				moteur de <em>Card Advantage</em> et non un réel moyen de tuer l'adversaire. De
				même, le fait de jouer la carte ne change pas de manière radicale la dynamique de
				la partie comme le ferait {{ living_end }} ou {{ balustrade_spy }}, c'est au mieux
				une menace pour l'adversaire.
			</p>
		</div>
		{% endtrans %}
		<div class="clear"></div>
	</li>
	<li>
		{% trans trimmed
			ci_psychatog='<span class=image>%(card)s</span>'|format(card=card_image("Psychatog"))|safe,
			how_to_grow_a_tog=external("https://articles.starcitygames.com/premium/so-many-insane-plays-how-to-groatog-and-almost-clip-a-lotus/","How to Grow-A-Tog and Clip a Lotus")
		%}
		<p>
			<strong>Aggro-Contrôle-Combo</strong>
		</p>
		<p>
			Catégorie et macrotype à part entière qui se caractérise par :
		</p>
		{{ ci_psychatog }}
		<ul>
			<li>
				Une condition de victoire qui consiste à gagner en attaquant avec ses créatures ;
			</li>
			<li>
				Une condition de victoire non-interactive basée sur une combo ;
			</li>
			<li>
				Une volonté de gérer le board que ce soit de manière proactive ou réactive.
			</li>
		</ul>
		<p>
			Les decks Aggro-Control-Combo sont extrêmement rares en dehors du Vintage car peu de
			decks sont capables de produire des plans de jeux aussi variés de manière efficace. Le
			deck Grow-A-Tog est repris à titre d'exemple dans cette catégorie dans un article de
			Stephen Menendian et Paul Mastriano de 2003 : {{ how_to_grow_a_tog }}.
		</p>
		{% endtrans %}
		<div class="clear"></div>
	</li>
</ol>
{% endblock %}
