{% extends "layout.html" %}

{% block title %}
Section Cartes thématiques
{% endblock %}

{% block content %}
<h1>{{ _("Cartes thématiques") }}</h1>
<p>
	{% trans %}
	Cette section explore les cartes les plus jouées du format <strong>Duel Commander</strong> par
	thème.
	{% endtrans %}
</p>

<h2>{{ _("Mécaniques de la color pie") }}</h2>
{% trans trimmed
	mechanical_color_pie=external("https://magic.wizards.com/en/articles/archive/making-magic/mechanical-color-pie-2017-2017-06-05", "Mechanical Color Pie")
%}
<p>
	La <em>color pie</em> est le pentagramme des couleurs de Magic : blanc, bleu, noir, rouge et
	vert. Chaque mécanique de Magic est reliée, de près ou de loin, à ce pentagramme. En effet,
	des couleurs sont spécialisées dans certains domaines. Mark Rosewater, dans
	{{ mechanical_color_pie }}, présente un système de classification de ces mécaniques selon ce
	que les couleurs sont censée faire en priorité dans le jeu.
</p>
{% endtrans %}

{{ bootstrap.card("Ravages of War", "/cartes-thematiques/mecaniques-de-la-colorpie/la-destruction-de-permanents") }}
{{ bootstrap.card("Aura of Silence", "/cartes-thematiques/mecaniques-de-la-colorpie/les-cartes-de-taxe") }}
{{ bootstrap.card("God's Willing", "/cartes-thematiques/mecaniques-de-la-colorpie/la-protection") }}


{{ bootstrap.card("Counterspell", "/cartes-thematiques/mecaniques-de-la-colorpie/les-contresorts") }}
{{ bootstrap.card("Cyclonic Rift", "/cartes-thematiques/mecaniques-de-la-colorpie/le-bounce-de-permanents") }}
{{ bootstrap.card("Ponder", "/cartes-thematiques/mecaniques-de-la-colorpie/les-cantrips") }}

{{ bootstrap.card("Thoughtseize", "/cartes-thematiques/mecaniques-de-la-colorpie/la-defausse") }}
{{ bootstrap.card("Eliminate", "/cartes-thematiques/mecaniques-de-la-colorpie/la-gestion-de-creatures") }}
{{ bootstrap.card("Reanimate", "/cartes-thematiques/mecaniques-de-la-colorpie/la-reanimation-de-creatures") }}

{{ bootstrap.card("Lightning Bolt", "/cartes-thematiques/mecaniques-de-la-colorpie/les-degats-directs") }}
{{ bootstrap.card("Zurgo, Bellstriker", "/cartes-thematiques/mecaniques-de-la-colorpie/les-creatures-agressives") }}
{{ bootstrap.card("Faithless Looting", "/cartes-thematiques/mecaniques-de-la-colorpie/le-remplacement-de-cartes") }}

{{ bootstrap.card("Rampant Growth", "/cartes-thematiques/mecaniques-de-la-colorpie/le-ramp") }}
{{ bootstrap.card("Llanowar Elves", "/cartes-thematiques/mecaniques-de-la-colorpie/les-mana-dorks") }}
{{ bootstrap.card("Elder Gargaroth", "/cartes-thematiques/mecaniques-de-la-colorpie/les-grosses-creatures") }}
<!--
<h2>{{ _("Cartes par fonctionnalité") }}</h2>
{% trans trimmed %}
<p>
	Les cartes dans cette catégorie sont répertoriées par fonctionnalité et proposent donc toutes
	des méthodes proches pour arriver au même résultat.
</p>
{% endtrans %}
<ul>
	<li>{{ link("/cartes-thematiques/les-piocheurs") }}</li>
	<li>{{ link("/cartes-thematiques/les-spot-removals") }}</li>
	<li>{{ link("/cartes-thematiques/les-mass-removals") }}</li>
	<li><em>Les Tuteurs</em></li>
	<li><em>Les Cailloux</em></li>
</ul>

<h2>{{ _("Les cycles de terrains") }}</h2>
<ul>
	<li><em>Les Fetches</em></li>
	<li><em>Les Bilands</em></li>
	<li><em>Les Shocklands</em></li>
	<li><em>Les Painlands</em></li>
	<li><em>Les Checklands</em></li>
	<li><em>Les Fastlands</em></li>
</ul>
-->
<p>
	<em>D'autres articles à venir ...</em>
</p>
{% endblock %}
