{% macro deck() -%}
<table width=100% border=0 align=center cellspacing=0 cellpadding=0 style="border-radius:5px;border:1px gray solid;">
	<tr><td><div class=win_title>Deck - Machine de Turing</div></td></tr>
	<tr><td colspan=2><table border=0 width=100% cellpadding=0 cellspacing=0>
		<tr><td valign=top width=50%><table border=0 width=100% cellspacing=0>
			<tr><td class=O14 align=center>4</td><td colspan=2 class=O14>Terrains</td></tr>
			<tr height=20><td width=30 valign=top align=center>4</td><td width=200 valign=top>{{card("Ancient Tomb")}}</td><td width=90 valign=top></td></tr>
			<tr><td class=O14 height=25 valign=bottom align=center>10</td><td colspan=2 class=O14 height=25 valign=bottom>Créatures</td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Fathom Feeder")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Xathrid Necromancer")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Rotlung Reanimator")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Fungus Sliver")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/3.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Soul Snuffers")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{ card("Olivia Voldaren")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/R.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Vigor")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/3.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Memnarch")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/7.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Djinn Illuminatus")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/5.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/UR.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/UR.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Blazing Archon")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/6.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/W.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/W.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/W.png></td></tr>
			<tr ><td class=O14 height=25 valign=bottom align=center>1</td><td colspan=2 class=O14 height=25 valign=bottom>Planeswalker</td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Karn Liberated")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/7.png></td></tr>
			<tr ><td class=O14 height=25 valign=bottom align=center>20</td><td colspan=2 class=O14 height=25 valign=bottom>Artefacts</td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Claws of Gix")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/0.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>4</td><td width=200 valign=top>{{card("Lotus Petal")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/0.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Reito Lantern")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>4</td><td width=200 valign=top>{{card("Grim Monolith")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Mesmeric Orb")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>4</td><td width=200 valign=top>{{card("Staff of Domination")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/3.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>4</td><td width=200 valign=top>{{card("Gemstone Array")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/4.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Riptide Replicator")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/X.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/4.png></td></tr></table>
		</td><td valign=top width=50%><table border=0 width=100% cellspacing=0>
			<tr ><td class=O14 align=center>15</td><td colspan=2 class=O14>Enchantements</td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Cloak of Invisibility")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Dread of Night")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Shared Triumph")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/1.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/W.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Prismatic Omen")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/1.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Steely Resolve")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/1.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>4</td><td width=200 valign=top>{{card("Power Artifact")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Wheel of Sun and Moon")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/WG.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/WG.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Suffocation")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Illusory Gains")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/3.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Privileged Position")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/WG.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/WG.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/WG.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Wild Evocation")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/5.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/R.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Recycle")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/4.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png></td></tr>
			<tr ><td class=O14 height=25 valign=bottom align=center>6</td><td colspan=2 class=O14 height=25 valign=bottom>Éphémères</td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Prismatic Lace")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Artificial Evolution")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Reality Ripple")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/1.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Glamerdye")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/1.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Capsize")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/1.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Cleansing Beam")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/4.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/R.png></td></tr>
			<tr ><td class=O14 height=25 valign=bottom align=center>4</td><td colspan=2 class=O14 height=25 valign=bottom>Rituels</td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Donate")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/2.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Infest")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/1.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Stolen Identity")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/4.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png></td></tr>
			<tr height=20><td width=30 valign=top align=center>1</td><td width=200 valign=top>{{card("Coalition Victory")}}</td><td width=90 valign=top><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/3.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/W.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/U.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/B.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/R.png><img  height=16 src=https://www.magic-ville.com/fr/graph/manas/big_png/G.png></td>
			</tr>
		</table></td></tr>
	</table></td></tr>
</table>
{%- endmacro %}
