{% extends "archetypes/_layout.html" %}
{% import "archetypes/_layout_wip.html" as layout with context %}
{% import "archetypes/kelsien-the-plague.json" as deck_json %}

{% block title %}
Kelsien, the Plague
{% endblock %}

{% block meta %}
<meta property="decklist" content='{{ deck_json | tojson }}' />
{% endblock %}

{% block archetype_name %}
<h1>Kelsien, the Plague</h1>
{% endblock %}

{% block archetype %}
<h2>Présentation rapide</h2>
<p>
	Le principe du deck est assez classique dans la forme : jouer trois bêtes sur les premiers tours pour soit mettre de la pression, soit occuper le board, en fonction du MU. En soutien le deck s'appuie sur une sélection de sorts polyvalents et un haut de curve orienté midrange.
</p>
<p>
	La particularité du deck et du build réside dans le fait qu’il est pensé pour être bicéphale :
</p>
<p>
	Contre aggro, Kelsien donne une grosse dominance de board grâce au ping. D'abord parce que bien sûr il tue les X/1, mais surtout parce que les phases d'attaque et de block deviennent des puzzles très complexes pour l'adversaire.
</p>
<p>
	Contre contrôle, on swap dans Marchesa. En forçant l'adversaire à réagir sur les trois premiers tours on trouve assez facilement une fenêtre pour résoudre la reine, ce qui permet de tenir le long terme beaucoup plus facilement qu'un aggro classique et compense bien le manque relatif de puissance de feu.
</p>
<p>
	C’est donc un deck aggro polyvalent avec des match-ups très lissés. Il est à son meilleur dans les duels de créatures et contre les decks trop mous qu’il peut asphyxier au monarque, et il rencontre ses plus grosses difficultés contre les decks combos sans créature avec lesquels il lui est difficile d'interagir.
</p>
{% endblock %}
