{% extends "articles/complexite-et-machine-de-turing/_layout.html" %}

{% block section %}
{% trans trimmed
	ensnaring_bridge=card("Ensnaring Bridge"),
	carnophage=card("Carnophage"),
	fretwork_colony=card("Fretwork Colony"),
	axis_of_immortality=card("Axis of Immortality"),
	recycle=card("Recycle"),
	oath_of_mages=card("Oath of Mages"),
	subversion=card("Subversion"),
	vampire_lacerator=card("Vampire Lacerator"),
	triskaidekaphobia=card("Triskaidekaphobia"),
	bitterblossom=card("Bitterblossom"),
	vile_consumption=card("Vile Consumption")
%}
<h3>Un jeu de Nim pour se détendre</h3>
<p>
	Allez terminons cet article par une note légère. Parlons du jeu de Nim aussi appelé, le jeu des
	bâtonnets. Ce jeu a été notamment popularisé en France par l'émission Fort Boyard. Il s'agit
	d'un jeu se jouant avec un ensemble de petits bâtonnets. Tour à tour les deux joueurs doivent
	en retirer 1, 2 ou 3 et celui qui retire le dernier perd la partie.
</p>
<p>
	Là vous vous demandez certainement ce que vient faire cette Appendice dans cet article. Eh bien
	disons qu'il s'agit d'une tradition... Je ne connais en effet aucun livre sérieux parlant de
	résolution de jeu qui ne parle pas à un moment ou un autre du jeu de Nim, car ce jeu et ses
	variantes sont en effet à la base de la théorie combinatoire des jeux. Le jeu de Nim est résolu
	et contrairement aux jeux précédent cités dans cet article, cette résolution a été obtenue sans
	avoir recours à la puissance du calcul informatique. Dans ce cas précis, la stratégie pour
	gagner consiste à laisser toujours à votre adversaire un nombre de bâtonnets de la forme 4n+1
	lorsque c'est à lui de jouer.
</p>
<p>
	Ce qui est au final étonnant avec le jeu de Nim, c'est qu'il peut être perçu comme une sous-
	partie de Magic ! Il est en effet théoriquement possible de mettre deux joueurs dans une
	situation de jeu à Magic où ils sont forcés de jouer à un jeu de Nim. Pour cela il suffit que
	chaque joueur contrôle {{ ensnaring_bridge }}, 2 {{ carnophage}}, {{fretwork_colony }},
	{{ axis_of_immortality }}, {{ recycle }} et qu'aucun joueur n'ait de cartes en main.
</p>
<p>
	Les joueurs ne piochent pas, ne peuvent pas attaquer et ne peuvent rien jouer. Les seuls
	actions qu'ils vont pouvoir faire vont se passer à leur entretien et vont concerner les
	{{ carnophage }} et {{ axis_of_immortality }} qu'ils contrôlent.
</p>
<p>
	Ici c'est le total de points de vie des deux joueurs qui va nous intéresser. Tour à tour, les
	joueurs vont pouvoir à l'entretien diminuer ce total de point de vie de 1, 2 ou 3 grâce à
	{{ carnophage }}, {{ fretwork_colony }} et {{ axis_of_immortality }}. Lorsqu'il ne restera plus
	qu'un point de vie à chaque joueur, le prochain joueur dont c'est l'entretien ne pourra plus
	perdre de point de vie sans perdre la partie. On a donc bien construit un jeu de Nim dans une
	partie de Magic où le nombre de points de vie total correspond au nombre de bâtonnets augmenté
	de un.
</p>
<p>
	On peut aussi créer tout un tas de variantes du jeu de Nim :
</p>
<ul>
	<li>
		en multipliant bien entendu les {{ carnophage }} et {{ fretwork_colony }}
	</li>
	<li>
		en rendant le jeu asymétrique
	</li>
	<li>
		en ajoutant des joueurs et des {{ axis_of_immortality }}
	</li>
	<li>
		en utilisant d'autres cartes marrantes comme : {{ oath_of_mages }}, {{ subversion }},
		{{ vampire_lacerator }}, ou encore {{ triskaidekaphobia }}.
	</li>
	<li>
		Après j'ai un faible personnellement pour les versions qui utilisent : {{ bitterblossom }}
		+ {{ vile_consumption }} puisqu'ici le nombre d'options qui s'offrent aux joueurs peut
		changer à chaque tour.
	</li>
</ul>
{% endtrans %}

{% trans trimmed
	turing_complete=external("https://arxiv.org/pdf/1904.09828.pdf","Magic : the Gathering is Turing Complete"),
	accidentally_turing=external("http://beza1e1.tuxen.de/articles/accidentally_turing_complete.html","Accidentally Turing-Complete"),
	chaine_deepmind=external("https://www.youtube.com/channel/UCP7jMXSY2xbc3KCAE0MHQ-A","Chaine Youtube DeepMind"),
	deepmind=external("https://www.numerama.com/sciences/458286-comment-deepmind-a-entraine-son-ia-pour-battre-des-champions-humains-sur-starcraft-2.html","Comment DeepMind a entrainé son I.A. pour battre des champions ..."),
	checkers_solved=external("https://www.researchgate.net/publication/231216842_Checkers_Is_Solved","Checkers is Solved")
%}
<h3>Liens externes</h3>
<ul>
	<li>
		{{ turing_complete }} : La publication scientifique originale qui a inspiré cet article.
	</li>
	<li>
		{{ accidentally_turing }} : Quelques jeux et systèmes qui se sont avéré contre toute
		attente Turing-complet (à l'intérieur desquels ont peut construire une Machine de Turing).
	</li>
	<li>
		{{ chaine_deepmind }} : Les cinq parties de Lee Sedol contre AlphaGo filmées.
	</li>
	<li>
		{{ deepmind }}
	</li>
	<li>
		{{ checkers_solved }} : La publication scientifique affirmant que le jeu de dame 8x8 a été résolu.
	</li>
</ul>
{% endtrans %}
{% endblock %}
