:root {
	--light-color: #e3e7e9;
	--dark-color: #222831;

	--brown-color: #8d8176;
	--orange-color: #f2a365;
	--blue-color: #30475e;
	--grey-color: #444444;
	--green-color: #306d44;

	--warning-light: #E48586;
	--warning-dark: #911419;

	--decklist-light: #A0C49F;
	--decklist-dark: #556052;
}

.btn-toggle {
	display: block;
	text-indent: -9999px;
	width: 24px;
	height: 24px;
	cursor: pointer;
}

@font-face {
	font-family: "FontAwesome";
	font-weight: 900;
	src: url("/static/fonts/fa-solid-900.ttf") format("truetype"),
		url("/static/fonts/fa-solid-900.svg") format("svg"),
		url("/static/fonts/fa-solid-900.woff") format("woff"),
		url("/static/fonts/fa-solid-900.woff2") format("woff2"),
		url("/static/fonts/fa-solid-900.eot") format("embedded-opentype");
}
@font-face {
	font-family: "FontAwesome Brand";
	font-weight: 400;
	src: url("/static/fonts/fa-brands-400.ttf") format("truetype"),
		url("/static/fonts/fa-brands-400.svg") format("svg"),
		url("/static/fonts/fa-brands-400.woff") format("woff"),
		url("/static/fonts/fa-brands-400.woff2") format("woff2"),
		url("/static/fonts/fa-brands-400.eot") format("embedded-opentype");
}

body {
	font-family: "Times New Roman", Times, serif;
	margin: 1em;
	-webkit-font-smoothing: antialiased;
}
article p {
	margin-bottom: 1em;
}
a {
	background-color: transparent;
	cursor: pointer;
}
header a,
footer a {
	text-decoration: none;
}
header,
footer {
	display: flex;
	flex-flow: row;
	padding: 2%;
	padding-left: 4%;
	padding-right: 4%;
	align-items: center;
	clear: both;
}
header a {
	display: flex;
	margin-right: auto;
}
header img {
	display: flex;
	margin-top: auto;
	margin-bottom: auto;
	width: 150px;
	height: 150px;
}
h1 {
	font-size: 2.5rem;
	padding: 0.5em;
	padding-top: 0.6em;
	text-align: left;
}
h1 > span {
	font-size: 0.5em;
	font-style: italic;
}
article span img {
	margin-left: 8px;
	margin-right: 8px;
}
h1 > img {
	height: 1.5em;
	max-width: 2em;
	vertical-align: middle;
}
h2 {
	font-size: 1.5rem;
	margin-top: 1em;
	margin-bottom: 0.5em;
	text-align: left;
}
h2 > img {
	height: 1.5rem;
	max-width: 2em;
	vertical-align: middle;
}
.modal {
	z-index: 3;
	display: none;
	padding: 5em;
	padding-top: 10em;
	padding-left: 0.5em;
	position: fixed;
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	overflow: auto;
	background-color: rgba(0, 0, 0, 0.4);
}
.hover-modal {
	z-index: 4;
	display: none;
	padding: 5em;
	padding-top: 10em;
	padding-left: 0.5em;
	position: fixed;
	left: 0;
	top: 0;
	overflow: hidden;
}
.modal-content {
	padding: 0;
	outline: 0;
	max-width: 300px;
	margin: 0.5em;
}
.modal-nav {
	font-family: "FontAwesome";
	max-width: 300px;
	font-weight: 900;
	font-size: 2em;
	text-align: center;
}
h3 {
	font-size: 1.2rem;
	margin-top: 0.8em;
	margin-bottom: 0.5em;
	text-align: left;
}
h3 > img {
	height: 1.2rem;
	max-width: 2em;
	vertical-align: middle;
}
h4 {
	font-size: 1rem;
	margin-top: 0.6em;
	margin-bottom: 0.3em;
	text-align: left;
}
h4 > img {
	height: 2rem;
	max-width: 2em;
	vertical-align: middle;
}
nav {
	display: inline-flex;
	margin-left: auto;
	margin-right: auto;
}
nav ul {
	list-style: none;
	padding: 0;
}
nav li {
	float: left;
	padding: 1em 1em 0 0;
	position: relative;
}
footer {
	max-width: 700px;
	margin: 4em auto;
}
footer > nav > .prev::before {
	font-family: "FontAwesome";
	font-weight: 900;
	content: "\f053";
	padding: 0 0.5em;
}
footer > nav > .next::after {
	font-family: "FontAwesome";
	font-weight: 900;
	content: "\f054";
	padding: 0 0.5em;
}
footer a {
	display: inline-flex;
	padding: 1em;
}
footer img {
	display: inline-flex;
	max-width: 5em;
	margin: 0 1em;
	vertical-align: middle;
}
footer p {
	font-style: italic;
	font-size: 0.8em;
	max-width: 700px;
}
footer p a {
	padding: 0;
}
article {
	max-width: 700px;
	margin: 0 auto;
	text-align: center;
}
article > img {
	max-width: 700px;
	margin: 0 auto;
}
p {
	max-width: 700px;
	margin: 0.5em;
	text-align: left;
	margin-left: auto;
	margin-right: auto;
}
ul {
	max-width: 700px;
	margin-left: auto;
	margin-right: auto;
}
article li {
	margin: 0.2em;
	text-align: left;
	margin-left: auto;
	margin-right: auto;
}
article div {
	padding: 0.5em 2em;
	border-radius: 1em;
	margin: 1.5em;
	clear: both;
}
article > div > img {
	max-width: 50%;
	margin: 0 auto;
}
li > img {
	height: 1em;
	max-width: 2em;
	vertical-align: middle;
}
td > img {
	height: 1.5em;
	max-width: 2em;
	vertical-align: middle;
}
table {
	border-collapse: collapse;
}
td {
	text-align: left;
	text-overflow: ellipsis;
	overflow: hidden;
	white-space: nowrap;
	border: none;
}
.article-columns {
	max-width: 1200px;
}
.article-columns div.tip {
	margin: 1.5em auto;
}
.icon {
	display: inline-block;
	font-style: normal;
	font-variant: normal;
	text-rendering: auto;
	line-height: 1;
}
.td-icon {
	text-align: center;
	vertical-align: center;
}
.brand-icon {
	font-family: "FontAwesome Brand";
}
.card {
	text-decoration: none;
	cursor: pointer;
}
.align-left {
	padding: 0;
	margin: 0;
	border: 0;
	text-align: left;
}
.column {
	display: inline-block;
	width: 270px;
	padding: 0;
	vertical-align: top;
	margin: 0.7em;
}
.wide-column {
	display: inline-block;
	width: 325px;
	padding: 0;
	vertical-align: top;
	margin: 0.7em;
}
.triple-column {
	display: inline-block;
	padding: 0.1em;
	vertical-align: top;
	margin: 0.7em;
	width: 28%;
}
.double-column {
	display: inline-block;
	padding: 0.1em;
	vertical-align: top;
	margin: 0.1em;
	width: 47%;
}
.column-image {
	margin: 0;
	padding: 0;
	text-align: center;
}
.column-image img {
	width: 80%;
}
.tip {
	max-width: 700px;
	clear: both;
}
.tip h3::before {
	font-family: "FontAwesome";
	font-weight: 900;
	content: "\f0eb";
	font-size: 1.5em;
	margin-right: 0.5em;
}
.warning {
	clear: both;
}
.warning h3::before {
	font-family: "FontAwesome";
	font-weight: 900;
	content: "\f071";
	font-size: 1.5em;
	margin-right: 0.5em;
}
.author {
	max-width: 700px;
	clear: both;
	vertical-align: middle;
}
.author > img {
	margin: auto 1em auto 0;
	max-width: 100px;
	max-height: 100px;
	float: left
}
.author > p {
	font-style: italic;
}
.decklist {
	float: left;
	padding: 0.5em;
	padding-left: 1em;
	margin: 0 1.5em 1.5em 0;
}
.decklist h2 {
	font-size: 1.5rem;
	margin-top: 0.2em;
	margin-bottom: 0;
}
.decklist h3 {
	font-size: 1.1rem;
	margin-top: 0.5em;
	margin-bottom: 0;
}
.decklist h4 {
	font-size: 1rem;
	margin-top: 0.4em;
	margin-bottom: 0;
}
.decklist p {
	font-size: 0.8em;
	font-style: italic;
}
.decklist ul {
	list-style: none;
	margin: 0;
	padding: 0.5em;
	padding-top: 0;
}
.decklist .card {
	font-style: normal;
	text-decoration: none;
	cursor: pointer;
}
.card-results {
	padding: 0;
}
.center-subtitle,
.subtitle {
	font-style: italic;
	font-size: 0.8em;
}
.center-subtitle {
	text-align: center;
}
.result-image-div {
	float: left;
	padding: 0.5em;
	padding-left: 0em;
	margin: 0 1.5em 1.5em 0;
}
.result-image {
	margin: auto;
	padding: 0;
	outline: 0;
	width: 300px;
}
.code {
	font-family: "Courier New", Courier, monospace;
	font-size: small;
	font-weight: 500;
}

@media only screen and (max-width: 750px) {
	header,
	footer {
		padding-left: 2%;
		padding-right: 2%;
		flex-direction: column;
	}
	header img {
		max-width: 60px;
		max-height: 60px;
	}
	h1 {
		font-size: 1.5rem;
		clear: both;
	}
	h1 > img {
		height: 40px;
	}
	.modal {
		padding: 5vh 5vw;
	}
	.modal-content {
		max-height: 70vh;
		max-width: 85vw;
	}
	.modal-nav {
		max-height: 15vh;
		max-width: 85vw;
	}
	h2 {
		clear: both;
	}
	.decklist {
		float: none;
	}
	.game-diagram-row {
		margin: 0.5em;
		margin-bottom: 2em;
	}
	.game-image {
		margin:0 0.2em;
		max-width: 50px;
	}
	.attached-1 {
		top: -0.5em;
		left: 0.5em;
	}
	.attached-2 {
		top: -1em;
		left: 1em;
	}
	.attached-3{
		top: -1.5em;
		left: 1.5em;
	}
	.attached-4{
		top: -2em;
		left: 2em;
	}
	article div {
		margin: 1.5em 0;
		padding: 0.5em 1em;
	}
	.triple-column {
		width: 100%;
		display: block;
	}
	.double-column {
		width: 100%;
		display: block;
	}
	#gist {
		max-width: 100%;
		margin: 0 auto;
	}
}
.clear {
	padding: 0;
	margin: 0;
	border: 0;
	clear: both;
}
#gist {
	max-width: 900px;
	margin: 0 auto;
}
#gist div {
	padding: 0.3em;
	margin: 0;
}
